### A Pluto.jl notebook ###
# v0.19.27

using Markdown
using InteractiveUtils

# This Pluto notebook uses @bind for interactivity. When running this notebook outside of Pluto, the following 'mock version' of @bind gives bound variables a default value (instead of an error).
macro bind(def, element)
    quote
        local iv = try Base.loaded_modules[Base.PkgId(Base.UUID("6e696c72-6542-2067-7265-42206c756150"), "AbstractPlutoDingetjes")].Bonds.initial_value catch; b -> missing; end
        local el = $(esc(element))
        global $(esc(def)) = Core.applicable(Base.get, el) ? Base.get(el) : iv(el)
        el
    end
end

# ╔═╡ 20222023-0236-0003-0000-000000000000
begin
	using PlotlyBase, HypertextLiteral, PlutoUI, PlutoTeachingTools
	using CSV, DataFrames, Dates, PeriodicalDates, StatsBase
end

# ╔═╡ 20222023-0236-0003-0000-000000000003
function Base.show(io::IO, mimetype::MIME"text/html", plt::PlotlyBase.Plot)
    # Remove responsive flag on the plot as we handle responsivity via ResizeObeserver and leaving it on makes the div flickr during updates
 hasproperty(plt,:config) && plt.config.responsive && (plt.config.responsive = false)   
 show(io,mimetype, @htl("""
         <div>
         <script id=asdf>
         const {plotly} = await import("https://cdn.plot.ly/plotly-2.2.0.min.js")
         const PLOT = this ?? document.createElement("div");
     

     
         Plotly.react(PLOT, $(HypertextLiteral.JavaScript(PlotlyBase.json(plt))));


     
         const pluto_output = currentScript.parentElement.closest('pluto-output')

         const resizeObserver = new ResizeObserver(entries => {
             Plotly.Plots.resize(PLOT)
         })

         resizeObserver.observe(pluto_output)

         invalidation.then(() => {
             resizeObserver.disconnect()
         })
     
         return PLOT
         </script>
         </div>
 """))
end;

# ╔═╡ 20222023-0236-0003-0000-000000000004
html"""
<picture>
  <source srcset="https://gci.iscte-iul.pt/2022/identidade/files/brand_v2/escolas/rgb/ibs/en/horizontal/negative/rgb_ibs_en_horizontal_negative.png" media="(prefers-color-scheme: dark)" width="240px!important" style="float:right;">
  <img src="https://gci.iscte-iul.pt/2022/identidade/files/brand_v2/escolas/rgb/ibs/en/horizontal/main/rgb_ibs_en_horizontal_main.png" width="240px" style="float:right;">
</picture>
<title>Macroeconomics</title>
<subtitle>Sample Exam</subtitle>
<semester>Degree in Management<br>First semester 2022-23</semester>
<author>Vivaldo Mendes, Luís Clemente-Casinhas, Ricardo Gouveia-Mendes</author>
"""

# ╔═╡ 73318fbe-9f98-4c53-8cf7-a43f4a6b0979
@bind nome TextField(66, placeholder="Name")

# ╔═╡ f2d282fa-8f08-49b9-9d81-c4cb507ff75a
@bind numero TextField(placeholder="Student number")

# ╔═╡ 9a192d29-9b7c-40a0-9c70-d392e684ddfc
md"""
> The test consists of 40 **multiple choice** questions. In each question, select **the correct alternative**, unless you are told otherwise.
>
> Each multiple-choice question is worth **0.5 points**.
>
> **Wrong answers deduct -0.125 points**.
>
> It is expected that this model test **will only take 1 hour to complete**.
>
> ---
>
> **NOTE:** In the real test, there will be 50 questions and the solving time will be 1h30.
"""

# ╔═╡ c1e263c9-5b33-41a8-ba01-ee05a4fb6ecc
md"""
---
"""

# ╔═╡ 46598cde-557e-4564-958b-9d3c3df029ed
Resource("https://vivaldomendes.org/images/Tests/Cycles_France.svg")

# ╔═╡ 20222023-0236-0003-0001-000000000001
md"""
The figure above shows the short-term economic cycles for France between 1950 and 2021. Two years in which France was in a deep economic recession are:

**a)** 2009 and 2020.

**b)** 1980 and 1990.

**c)** 1960 and 1970.

**d)** 1975 and 2000.

**e)** None of the above.
"""

# ╔═╡ 20222023-0236-0003-0001-000000000002
@bind q01 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 810e0feb-4061-4461-8d58-fbe72634f8df
md"""
---
"""

# ╔═╡ 20222023-0236-0003-0002-000000000001
md"""
For a given economy, it is known that GDP = 98 and that Potential GDP = 100. Select the correct option.

**a)** The economy is in a recession and the output gap is equal to 2.

**b)** The economy is in an economic boom and the output gap is -2.

**c)** The economy is in a recession and the output gap is -2.

**d)** The economy is in an economic boom and the output gap is equal to 2.

**e)** None of the above.
"""

# ╔═╡ 20222023-0236-0003-0002-000000000002
@bind q02 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 22ae6f1e-8a54-4a36-9ac2-bb96b2c92bae
md"""
---
"""

# ╔═╡ 20222023-0236-0003-0003-000000000001
md"""
In a macroeconomic model, endogenous variables are:

**a)** variables whose value is determined outside the model.

**b)** variables generated internally in a given country or geographical area.

**c)** variables whose value or evolution is to be explained by the model.

**d)** variables whose behavior cannot be explained.

**e)** variables on which there is no scientific consensus.
"""

# ╔═╡ 20222023-0236-0003-0003-000000000002
@bind q03 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ bb8cfda6-3efb-4c17-b99b-cc195690518a
md"""
---
"""

# ╔═╡ 20222023-0236-0003-0004-000000000001
md"""
In a macroeconomic model, there are endogenous and exogenous variables. Select the false option about endogenous variables:

**a)** They are determined within a model.

**b)** They cannot determine exogenous variables.

**c)** They can determine other endogenous variables.

**d)** They are not always determined by exogenous variables.

**e)** They are determined outside an economic model.
"""

# ╔═╡ 20222023-0236-0003-0004-000000000002
@bind q04 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 276db795-6ab4-4501-81c6-88392a9d63c1
md"""
---
"""

# ╔═╡ 20222023-0236-0003-0005-000000000000
md"""
Consider an economy where only the following goods are produced:

| Goods  |   |  $~~~~~~~~~~~~~~$ Year 1 |      |    ||$~~~~~~~~~~~~~~$Year 2||
|:----   |---| :----:          | :----: |   ---|--- |:----:        | :----: |
|        |   | Quantities      | Prices |      |    |Quantities    | Prices |
|Milk    |   | 5000            | 2      |      |    |4900          | 2.1    |
|Bread   |   | 1000            | 1.5    |      |    |1400          | 1.6    |

"""

# ╔═╡ 20222023-0236-0003-0005-000000000001
md"""
The nominal GDP for years 1 and 2 will be, respectively:

**a)** GDP1 = 12530; GDP2 = 11500.

**b)** GDP1 = 11500; GDP2 = 12530.

**c)** GDP1 = 15000; GDP2 = 10000.

**d)** GDP1 = 10000; GDP2 = 15000.

**e)** None of the above.
"""

# ╔═╡ a427ead0-0317-4c00-9cf8-fb162cd771c2
# Célula livre para cálculos

# ╔═╡ 5a10b2ee-1cc6-4bdd-b793-d7e584b410e5
# Célula livre para cálculos

# ╔═╡ 38424a48-bc9e-471d-9773-171fd8effb55
# Célula livre para cálculos

# ╔═╡ 20222023-0236-0003-0005-000000000002
@bind q05 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ de3e42e5-c0a7-4cda-b57c-71e26acef295
md"""
---
"""

# ╔═╡ 20222023-0236-0003-0006-000000000001
md"""
The special imputations associated with the calculation of GDP serve to:

**a)** Include in GDP the value of Goods & Services that are not subject to market transactions.

**b)** Include in GDP, those Goods & Services transactions that are not declared to the tax authorities.

**c)** Include illegal Goods & Services transactions in GDP.

**d)** Avoid artificial increases in GDP due to double counting.

**e)** None of the above.
"""

# ╔═╡ 20222023-0236-0003-0006-000000000002
@bind q06 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 92dcdd60-e9a0-42e8-beca-15122a00171b
md"""
---
"""

# ╔═╡ 20222023-0236-0003-0007-000000000001
md"""
Consider a simple economy where there are two goods: grapes and wine. It is known that this economy produces 1000 dollars of grapes and 5000 dollars of wine, and the wine companies buy all the grapes to produce wine. Based on this information, what methods can be used to calculate the value of GDP in this case?

**a)** The expenditure method and the income method.

**b)** The production method and the income method.

**c)** Only the expenditure method.

**d)** Only the production method.

**e)** None of the above.

"""

# ╔═╡ 20222023-0236-0003-0007-000000000002
@bind q07 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ f8a19733-f839-41ab-94bc-b8499dfbb0eb
md"""
---
"""

# ╔═╡ 20222023-0236-0003-0008-000000000001
md"""
TAP sold used planes worth 0.5 millions to Ryanair in the UK in order to pay some compensation. The impact of the aircraft sale on the Portuguese GDP is:

**a)** Increase by 0.5 millions.

**b)** Decrease by 0.5 millions.

**c)** The operation has no impact on GDP.

**d)** There is not enough data to calculate the impact on GDP.

**e)** None of the above.
"""

# ╔═╡ 20222023-0236-0003-0008-000000000002
@bind q08 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 5b356213-6c8d-4d2c-a6fd-08cab027ea76
md"""
---
"""

# ╔═╡ 20222023-0236-0003-0009-000000000010
let
C̄ = 2.0;  Ī = 1.5 ;  Ḡ = 2.5;  T̄ = 2.5; N̄X̄ = 1.0; f̄ = 1.0; c = 0.5; b = 0.1; d = 0.5; x = 0.15;
Ā = C̄ + Ī - d*f̄ + Ḡ + N̄X̄ - c*T̄
m = 1/(1-c)
ϕ = b + d + x

Y = 0.0:0.01:15.0	
r = (Ā./ ϕ) .- (1. /(m .* ϕ)).*Y
trace4_1 = scatter(; x=Y, y = r, mode="lines" , line_color = "Blue", line_width = "3",
name  = "IS")

trace4_2 = scatter(; x = [6.0, 9.0], y = [3.0, 1.0], text =["1", "2"], textposition = "top center", 
                    name ="Eq.", mode="markers+text", marker_size= "12", marker_color="Blue", 
textfont = attr(family="sans serif", size=16, color="black"))


trace4_4A = scatter(; x = [7.0, 8.0], y = [1.0, 3.0], text =["2'", "1'"], textposition = "top center", 
                    name ="Eq.", mode="markers+text", marker_size= "12", marker_color="Red", 
textfont = attr(family="sans serif", size=16, color="black"))

layout4_2 = Layout(;
title_text = "The IS Curve", 
title_x = 0.5,
hovermode="x",
                    xaxis=attr(title="GDP in trillion dollars (Y)", showgrid=true, zeroline=false),
                    xaxis_range = [2.9, 12.0],
yaxis_range = [-1.0, 5.0],
                    yaxis=attr(title="Real interest rate (r)", zeroline = false))

p4_2 = Plot([trace4_1, trace4_2, trace4_4A], layout4_2)

end

# ╔═╡ 20222023-0236-0003-0009-000000000001
md"""
Using the figure "The IS Curve" and knowing that $m=2$, the economy moves from point 2 to point 2', due to the following fact:

**a)** Exogenous Consumption $(\overline{C})$ has increased by 1 trillion dollars.

**b)** Exogenous Consumption $(\overline{C})$ decreased by 1 trillion dollars.

**c)** The real interest rate $(r)$ decreased by 1 percentage point (1 pp).

**d)** Exogenous Consumption $(\overline{C})$ decreased by 2 trillion dollars.

**e)** None of the above.
"""

# ╔═╡ 20222023-0236-0003-0009-000000000002
@bind q09 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 5c281d9c-6dc0-40c5-96de-b44362a9a5dd
md"""
---
"""

# ╔═╡ 20222023-0236-0003-0010-000000000001
md"""
What is the economic significance of Autonomous Demand?

**It is an endogenous variable that represents a value of goods and services desired in a given economy that is not sensitive to changes in the interest rate.

**b)** It is an exogenous variable representing a value of goods and services desired in a given economy that is not sensitive to changes in the interest rate.

**c)** It is an endogenous variable representing a value of goods and services desired in a given economy that is not sensitive to changes in the inflation rate.

**d)** It is an exogenous variable representing a value of goods and services desired in a given economy that is sensitive to changes in the interest rate.

**It is an exogenous variable representing a value of goods and services desired in a given economy that is sensitive to changes in the inflation rate.
"""

# ╔═╡ 20222023-0236-0003-0010-000000000002
@bind q10 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 8126a8db-43b0-4510-86b0-d988054cd77a
md"""
---
"""

# ╔═╡ 9031631e-3aa7-46de-973d-dbfa668bf18b
md"""
In the Goods & Services market, the following information is known:  

$$\overline{C} =2  \quad , \quad  \overline{I} =1.5 \quad , \quad \overline{G} = 2.5 \quad , \quad \overline{T} =2.5 \quad , \quad \overline{N X}= 1$$

$$\overline{f}  =1 \quad , \quad c=0.5 \quad , \quad b=0.1 \quad , \quad d=0.5 \quad , \quad x=0.15$$


The IS curve is represented in the following figure. Quantify two changes in Autonomous Demand that move the economy from point 1 to point 3.
"""

# ╔═╡ bece237e-83f1-41b5-a759-1c2934ddc57b
let
C̄ = 2.0;  Ī = 1.5 ;  Ḡ = 2.5;  T̄ = 2.5; N̄X̄ = 1.0; f̄ = 1.0; c = 0.5; b = 0.1; d = 0.5; x = 0.15;
Ā = C̄ + Ī - d*f̄ + Ḡ + N̄X̄ - c*T̄
m = 1/(1-c)
ϕ = b + d + x

Y = 0.0:0.01:15.0	
r = (Ā./ ϕ) .- (1. /(m .* ϕ)).*Y
trace4_1 = scatter(; x=Y, y = r, mode="lines" , line_color = "Blue", line_width = "3",
name  = "IS")

trace4_2 = scatter(; x = [6.0, 9.0], y = [3.0, 1.0], text =["1", "2"], textposition = "top center", 
                    name ="Eq.", mode="markers+text", marker_size= "12", marker_color="Blue", 
textfont = attr(family="sans serif", size=16, color="black"))


trace4_4A = scatter(; x = [7.0, 9.0], y = [1.0, 3.0], text =["2'", "3"], textposition = "top center", 
                    name ="Eq.", mode="markers+text", marker_size= "12", marker_color="Red", 
textfont = attr(family="sans serif", size=16, color="black"))

layout4_2 = Layout(;
title_text = "IS Curve", 
title_x = 0.5,
hovermode="x",
                    xaxis=attr(title="GDP in trillion dollars (Y)", showgrid=true, zeroline=false),
                    xaxis_range = [2.9, 12.0],
yaxis_range = [-1.0, 5.0],
                    yaxis=attr(title="Real interest rate (r)", zeroline = false))

p4_2 = Plot([trace4_1, trace4_2, trace4_4A], layout4_2)

end

# ╔═╡ 20222023-0236-0003-0011-000000000001
md"""

**a)** $\Delta\overline{NX} = 0.75$ e $\Delta\overline{I} = 0.75$.

**b)** $\Delta\overline{NX} = -2$ e $\Delta\overline{I} = -2$.

**c)** $\Delta\overline{I} = 2$ e $\Delta m = 2$.

**d)** $\Delta\overline{G} = -2$ e $\Delta\overline{T} = 2$.

**e)** $\Delta\overline{G} = -2$ e $\Delta m = 2$.
"""

# ╔═╡ 20222023-0236-0003-0011-000000000002
@bind q11 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 563b85f3-c11e-4e9a-a98e-8d6b91be2d2d
md"""
---
"""

# ╔═╡ 2d8c34ef-9697-4d36-a66c-83fc800ef447
let
C̄ = 2.0;  Ī = 1.5 ;  Ḡ = 2.5;  T̄ = 2.5; N̄X̄ = 1.0; f̄ = 1.0; c = 0.5; b = 0.1; d = 0.5; x = 0.15;
Ā = C̄ + Ī - d*f̄ + Ḡ + N̄X̄ - c*T̄
m = 1/(1-c)
ϕ = b + d + x

Y = 0.0:0.01:15.0	
r = (Ā./ ϕ) .- (1. /(m .* ϕ)).*Y
	
	trace4_0 = scatter(; x=Y, y = r, mode="lines" , line_color = "Blue", line_width = "3",
					name  = "IS")
	
	layout4_0 = Layout(;
					title_text ="IS Curve", 
					title_x = 0.5,
					hovermode="x",
                    xaxis=attr(title="GDP in trillion dollars (Y)", showgrid=true, zeroline=false),
                    xaxis_range = [2.9, 12.0],
					yaxis_range = [-1.0, 5.0],
                    yaxis=attr(title="Real interest rate (r)", zeroline = false))

   p4_0 = Plot([trace4_0], layout4_0)
	
end

# ╔═╡ 20222023-0236-0003-0012-000000000001
md"""
Using the IS function shown above, if the real interest rate increases by 2p.p., the effect on GDP will be:

**a)** Increase by 2 trillion.

**b)** Decrease by 3 trillion.

**c)** Nil, as inflation will follow the rise in the interest rate.

**d)** Nil, as there will be a decrease in exports due to an appreciation of the currency.

**e)** Nil, as there will simply be a transfer from consumption to savings due to the higher interest rate.
"""

# ╔═╡ 20222023-0236-0003-0012-000000000002
@bind q12 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 06cd1a6f-a464-4961-8c23-f3c089075fab
md"""
---
"""

# ╔═╡ be4a5d64-8da8-419e-9b5c-4b66aac99cc4
html"""
<img src="https://vivaldomendes.org/images/Tests/MP.png" style="width:500px" />
"""

# ╔═╡ 20222023-0236-0003-0013-000000000001
md"""
Looking at the figure above, the shift in the MP curve from position 1 to position 2 means that:

**a)** The inflation rate decreases for each level of the real interest rate.

**b)** The inflation rate increases for each level of the real interest rate.

**c)** There is no relationship between the real interest rate and the inflation rate.

**d)** The inflation rate remains constant at each level of the real interest rate.

**e)** None of the above
"""

# ╔═╡ 20222023-0236-0003-0013-000000000002
@bind q13 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ e0b75cb6-72fa-4c04-ac91-ae029f45bc74
md"""
---
"""

# ╔═╡ 20222023-0236-0003-0014-000000000001
md"""
The central bank sets the real short-term interest rate based on the following 2 variables:

**a)** GDP and deflation.

**b)** Unemployment and GDP.

**c)** The nominal interest rate, and inflation

**d)** GDP and the price index.

**e)** None of the above.
"""

# ╔═╡ 20222023-0236-0003-0014-000000000002
@bind q14 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 6ee3b122-0946-4a07-ae46-8e8823f9c390
md"""
---
"""

# ╔═╡ b31c69f6-b072-4e95-aada-3d07a0e89481
begin
		Ā3 = 7.6 ;	λ3 = 0.5 ;	m3 = 2.0 ;	ϕ3 = 0.2 ;	r̄3 = 2.0 ;		
		r3 = 1.5:0.01:7.0
		π3 = - (r̄3 ./ λ3) .+  r3 ./ λ3
function fig_3b1()
		
		r3 = 1.5:0.01:7.0
	
		π3 = - (r̄3 ./ λ3) .+  r3 ./ λ3
	
		trace5_5 = scatter(; x = r3, y = π3, mode="lines" , line_color = "Brown", line_width = "3",
					name  = "MP")
	
		layout5_5 = Layout(;
					title_text ="MP curve", 
					title_x = 0.5,
					hovermode = "x",
                    xaxis=attr(title=" Real interest rate (r)", showgrid=true, zeroline=false),
                    xaxis_range = [1.5, 6.5],
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-1 ,9])

   		p5_5 = Plot([trace5_5], layout5_5)
		
	end
	#fig_3b1()

function fig_3b2()
		
		Y3 = 12.0:0.01:14.6
		πdmax3 = (Ā3 / (λ3 * ϕ3)) - r̄3/λ3 		# The AD curve y-axis intercept 
	
		πd3 = πdmax3 .- ((1 ./(m3 .* ϕ3 .* λ3)) .* Y3)
	
		trace5_6 = scatter(; x = Y3, y = πd3, mode="lines" , line_color = "Blue", line_width = "3",
					name  = "AD")
	
	
		layout5_6 = Layout(;
					title_text ="AD curve", 
					title_x = 0.5,
					hovermode = "x",
                    xaxis=attr(title=" GDP (Y)", showgrid=true, zeroline=false),
                    xaxis_range = [12.6, 14.6],
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-1 ,9])

   		p5_6 = Plot([trace5_6], layout5_6)
	end
	#fig_3b2()

	p5A_6A = [fig_3b1() fig_3b2()]
	relayout!(p5A_6A, hovermode = "y")
	p5A_6A
	
end

# ╔═╡ 20222023-0236-0003-0015-000000000001
md"""
The AD and MP curves are shown above. If inflation rises by 2 p.p., how will the central bank react?

**a)** The real interest rate will be around 3.9%.

**b)** GDP will be around 10.2 trillion.

**c)** The interest rate set by the central bank will be around 5.9%.

**d)** The central bank will raise the real interest rate by 1 p.p.

**e)** None of the above.
"""

# ╔═╡ 20222023-0236-0003-0015-000000000002
@bind q15 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ f24078ee-706e-48cf-8a44-4fa19e78b4c4
md"""
---
"""

# ╔═╡ f39350c4-2bf9-4e4a-8b8f-01bb4da07dc7

let
	Ā5 = 5.6 ; λ5 = 0.5 ; m5 = 2.0 ;	ϕ5 = 0.3 ; r̄5 = 0.5 		   	# Demand	
	γ5 = 4.0 ; Yᴾ5 = 10.0 ; πᵉ5 = 3.0 ; ρ5 = 0.0 ; 					# Supply		
	πd_max5 = (Ā5 / (λ5 * ϕ5)) - r̄5/λ5       							# The AD curve y-axis' intercept	
	πs_min5 = πᵉ5 - γ5 * Yᴾ5 + ρ5   

	Y5 = 9.0:0.01:11.0
	
	πd5 = πd_max5 .- ((1 ./(m5 .* ϕ5 .* λ5)) .* Y5) # AD function
	πs5 = πs_min5 .+ γ5 .*Y5             # AS function
	
	trace9_0 = scatter(; x = [10,10] , y = [-7,10] , mode = "line", line_width = "4", name = "Yp", 
					line_color = "Orange")
	
	trace9_1 = scatter(; x = Y5, y = πd5, mode="lines" , line_color = "Blue", line_width = "3",
			name  = "AD")
	
	trace9_2 = scatter(; x = Y5, y = πs5, mode="lines" , line_color = "Red", line_width = "3",
					name  = "AS")
	
	trace9_3 = scatter(; x = [10.0], y = [3.0], text =["1"], 
					textposition = "top center", name ="", mode="markers+text", marker_size= "12",
					marker_color="Blue", textcolor = "Black",
	 				textfont = attr(family="sans serif", size=18, color="black"))
	
	
	layout9_3 = Layout(;
					title_text = "Macroeconomic Equilibrium",
					title_x = 0.5,
					hovermode = "x",
                    xaxis=attr(title=" GDP trillion dollars (Y)", showgrid=true, zeroline=false),
                    xaxis_range = [9.2, 10.8],	
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-0.0 , 6.0])

	p9_3 = Plot([trace9_0, trace9_1, trace9_2, trace9_3], layout9_3)

	r5 = 0.0:0.01:5.0
	
		πmp5 = - (r̄5 ./ λ5) .+  r5 ./ λ5 
		
		trace4_0 = scatter(; x = r5, y = πmp5, mode="lines" , line_color = "Brown", line_width = "3",
				name  = "MP")
		
		trace4_1 = scatter(; x = [2.0], y = [3.0], text =["1"], 
						textposition = "top center", name ="", mode="markers+text", 
						marker_size= "12", marker_color="Brown", 
						textfont = attr(family="sans serif", size=18, color="black"))
		
		layout4_1 = Layout(;
						title_text = "MP Curve",
						title_x = 0.5,
						hovermode = "x",
	                    xaxis=attr(title=" Real interest rate (r)", showgrid=true, zeroline=false),
	                    xaxis_range = [0.5, 3.5],
						#xaxis_tickvals = [1, 1.5, 2, 2.5, 3, 3.5, 4],
	                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
						yaxis_range=[-0.0 , 6.0])
	
	   p4_1 = Plot([trace4_0, trace4_1], layout4_1)

[p4_1 p9_3]
end

# ╔═╡ 20222023-0236-0003-0016-000000000001
md"""
Taking into account the figures above, which represent the macroeconomic equilibrium, which of the figures below correspond to this equilibrium?

**a)** $\pi=3\% \ \  , \ \ Y = 10 \ \ , \ \ r=2.5\% \ \ , \ \ i = 5.5\%$.

**b)** $\pi=10\% \ \  , \ \ Y = 3 \ \ , \ \ r=2.5\% \ \ , \ \ i = 5.5\%$.

**c)** $\pi=2.5\% \ \  , \ \ Y = 10 \ \ , \ \ r=5.5\% \ \ , \ \ i = 10.5\%$.

**d)** $\pi=0\% \ \  , \ \ Y = 10 \ \ , \ \ r=5\% \ \ , \ \ i = 5\%$.

**e)** $\pi=3\% \ \  , \ \ Y = 10 \ \ , \ \ r=3\% \ \ , \ \ i = 6\%$.
"""

# ╔═╡ 20222023-0236-0003-0016-000000000002
@bind q16 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 01ba3e57-e781-4daf-a17f-56acf8534000
md"""
---
"""

# ╔═╡ 20222023-0236-0003-0017-000000000001
md"""
The money multiplier is not a relevant macroeconomic variable these days for the following reasons:

**a)** It is extremely unstable, even in the short term.

**b)** The central bank does not control the Monetary Base; therefore, it does not control this multiplier. 

**c)** The central bank perfectly controls the Money Supply (M2); therefore, it totally controls this multiplier.

**d)** Nobody knows how the monetary multiplier is calculated.

**e)** None of the above.
"""

# ╔═╡ 20222023-0236-0003-0017-000000000002
@bind q17 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 7706ce55-864e-41cb-bd94-707d04565701
md"""
---
"""

# ╔═╡ 20222023-0236-0003-0018-000000000001
md"""
The *Discount Rate* used by the Fed serves to:

**a)** Fine commercial banks that build up reserves above the legal limit.

**b)** Define the percentage of the amount received in deposits that cannot be granted in credit.

**c)** Increase the money multiplier.

**d)** Remunerate commercial banks for the reserves they have set aside with the Central Bank.

**e)** Set the price on the credit that the Central Bank grants to commercial banks.
"""

# ╔═╡ 20222023-0236-0003-0018-000000000002
@bind q18 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 6661f1d5-b9bc-450e-a628-50b4c9325b86
md"""
---
"""

# ╔═╡ 20222023-0236-0003-0019-000000000000
md"""
The Fed's balance sheet in 2021 is given by (for simplifity, these figures are approximate values):

| Assets              | $~~$ \$Billions  |       | Liabilities          | \$Billions
| :---------------    | ------------:    | :---: | :---------------     | -------:
| Foreign reserves    | 40               |       | Currency             | 2100
| Securities          | 8000             |       | Reserves     | 4400 
| Loans               | 100              |       | Other liabilities    | 1650
| Other assets        | 60               |       | Equity     | 50
| Total assets        | 8200             |       | Liabilities+Equity   | 8200

"""

# ╔═╡ 20222023-0236-0003-0019-000000000001
md"""
What was the value of the Monetary Base (MB) in the USA in 2021?

**a)** 2100 + 4400 + 1650 billions.

**b)** 8200 billions.

**c)** 2100 + 4400 billions.

**d)** 50 billions.

**e)** None of the above.
"""

# ╔═╡ f87ae88e-587e-4b9a-98b7-b2e4f4d72f90


# ╔═╡ 20222023-0236-0003-0019-000000000002
@bind q19 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 2dba2b8f-adfa-4900-a9df-222ca680cced
md"""
---
"""

# ╔═╡ 20222023-0236-0003-0020-000000000001
md"""
What would change on the Fed's balance sheet if it carried out the following transactions?
- It sells 500 million dollars in Treasuries (US government bonds);
- Buys 800 million dollars of Mortgage-Backed Securities.

**a)** Securities = --500 millions + 800 millions; Reserves = --500 millions + 800 millions.

**b)** Securities = +500 millions -- 800 millions ; Reserves = +500 millions -- 800 millions.

**c)** Securities = +1300 millions ; Reserves = +1300 millions.

**d)** Securities = --1300 millions ; Reserves = --1300 millions.

**e)** None of the above.
"""

# ╔═╡ 20222023-0236-0003-0020-000000000002
@bind q20 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ bd7c437b-c704-4072-bf25-2cb4b69d6c86
md"""
---
"""

# ╔═╡ 20222023-0236-0003-0021-000000000000
let
output = 0:1:16
PC = 3.0 .+(0.5 .* 0.5).*(output .- 10.0)
trace7_24 = scatter(;x =output, y = PC, 
name = "AS", line_color = "Blue", mode = "lines", 
line_width="2.5") 
trace7_25 = scatter(; x = [8.0, 10.0, 12.0], y = [2.5, 3.0 , 3.5], text = ["2", "1" , "3"], 
textposition = "top center", name = "", mode="markers+text", marker_size= "12",
marker_color="blue", 
textfont = attr(family="sans serif", size=16, color="black"))
trace7_49 = scatter(; x = [10.0, 10.0] , y = [-2,10] , mode = "line", line_width = "4", name = "Yp", 
line_color = "Orange") 
trace7_41 = scatter(; x = [8.0, 10.0, 12.0], y = [3.0, 3.5 , 4.0], text = ["2'", "1'" , "3'"], 
textposition = "top center", name = "", mode="markers+text", marker_size= "12",
marker_color="Red", 
textfont = attr(family="sans serif", size=16, color="black"))
layout7_25 = Layout(;
title_text = "The AS curve",
title_x = 0.5,
        yaxis_title = "Rate of Inflation",
yaxis_zeroline= false,
hovermode="x",
        xaxis_range = [6.0, 14.0],
        xaxis_title = "GDP (trillion dollars)",
xaxis_zeroline= false,
        yaxis_range=[2.0, 4.2], 
        titlefont_size=18) 
p7_25=Plot([trace7_49, trace7_24, trace7_25, trace7_41], layout7_25)
end

# ╔═╡ 20222023-0236-0003-0021-000000000001
md"""
In the figure above, how do you justify the shift in the AS curve from point 2 to 2'?

**a)** A positive shock to AS of $-0.5$ percentage points.

**b)** A rise in GDP by 2 trillions.

**c)** A decrease in GDP by 2 trillion dollars.

**d)** A negative shock to AS of $+0.5$ percentage points.

**e)** None of the above.
"""

# ╔═╡ 20222023-0236-0003-0021-000000000002
@bind q21 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 3ff3352b-8674-4213-929f-1591dc54039d
md"""
---
"""

# ╔═╡ 20222023-0236-0003-0022-000000000001
md"""
The Okun's Law tells us that:

**a)** If GDP $(Y)$ falls by 1 percentage point, the unemployment rate $(U)$ will increase by about 0.5 percentage points.

**b)** If GDP $(Y)$ falls by 1 percentage point, the unemployment rate $(U)$ will fall by around 0.5 percentage points.

**c)** If GDP $(Y)$ falls by 1 percentage point, the unemployment rate $(U)$ will remain unchanged.

**d)** If GDP $(Y)$ falls by 1 percentage point, the unemployment rate $(U)$ will rise by 10 percentage points.

**e)** If GDP $(Y)$ falls by 1 percentage point, it will automatically return to its initial value.
"""

# ╔═╡ 20222023-0236-0003-0022-000000000002
@bind q22 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 876643b7-e47a-425f-994b-66827243fbfd
md"""
---
"""

# ╔═╡ 20222023-0236-0003-0023-000000000001
md"""
One of the phenomena that could lead to an upward shift in the Phillips Curve is:

**a)** A decrease in the price of oil.

**b)** An increase in the unemployment rate.

**c)** A decrease in the natural rate of unemployment.

**d)** An increase in expected inflation.

**e)** None of the above.
"""

# ╔═╡ 20222023-0236-0003-0023-000000000002
@bind q23 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 6b3d603d-9bcb-467a-bbcb-4d499dfcf252
md"""
---
"""

# ╔═╡ 20222023-0236-0003-0024-000000000001
md"""
The idea behind the Phillips Curve is that:

**a)** Inflationary pressures are the result of the unemployment rate being below the natural rate of unemployment.

**b)** Wages rise when GDP is below potential GDP.

**c)** Inflationary pressures are the result of the unemployment rate being above the natural rate of unemployment.

**d)** Wages decrease when GDP is above potential GDP.

**e)** None of the above.
"""

# ╔═╡ 20222023-0236-0003-0024-000000000002
@bind q24 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ b9e82ce1-c5b0-4354-8fdd-791755a0f0fc
md"""
---
"""

# ╔═╡ 20222023-0236-0003-0025-000000000001
md"""
Assess the accuracy of the following statement: "The recent appreciation of the US dollar has had a negative impact on the US aggregate demand curve."

**a)** An appreciation of the US dollar will decrease US net exports. Therefore, aggregate demand will fall, and the sentence is correct.

**b)** An appreciation of the US dollar will increase US net exports. Therefore, aggregate demand will increase, and the sentence is incorrect.

**c)** An appreciation of the US dollar will not impact US net exports. Therefore, aggregate demand will decrease, and the sentence is incorrect.

**d)** US net exports do not depend on the value of the US dollar but on non-exchange rate forces; therefore, the sentence makes no sense.

**e)** None of the above.
"""

# ╔═╡ 20222023-0236-0003-0025-000000000002
@bind q25 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 3eb0d1e6-3e1e-454e-8939-ba79bc3e1a8e
md"""
---
"""

# ╔═╡ 20222023-0236-0003-0026-000000000001
md"""
A **permanent** positive shock to aggregate supply:

**a)** Makes the economy less efficient.

**b)** Promotes increases in the inflation rate.

**c)** Decreases aggregate output in the long term.

**d)** Can be caused by the adoption of reckless regulations.

**e)** None of the above.
"""

# ╔═╡ 20222023-0236-0003-0026-000000000002
@bind q26 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 6c350a26-356e-46a5-98d9-fa5e212cef37
md"""
---
"""

# ╔═╡ 20222023-0236-0003-0027-000000000001
md"""
According to the self-correcting mechanism, how does GDP return to the value of potential GDP after a negative shock to aggregate demand?

**a)** The negative shock to demand causes aggregate output to increase for each level of the inflation rate, promoting a positive output gap, which causes inflation to rise.

**b)** Expected inflation decreases, shifting the short-term aggregate supply curve downwards along the new aggregate demand curve.

**c)** Lower inflation leads to an automatic response from the central bank by increasing the real interest rate, stimulating planned spending, increasing aggregate output, and narrowing the output gap.

**d)** The negative shock to demand causes aggregate output to increase for each level of the inflation rate, promoting a negative output gap, which causes inflation to fall.

**e)** None of the above.
"""

# ╔═╡ 20222023-0236-0003-0027-000000000002
@bind q27 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ e698d7f3-9048-456a-8968-854c9f93039a
md"""
---
"""

# ╔═╡ 20222023-0236-0003-0028-000000000001
md"""
When Paul Volcker took over as the new Governor of the Federal Reserve in 1979, the inflation rate was over 10%. In 1982, the unemployment rate soared to 9.7%, and inflation fell to 6.2%. Which of the following is an appropriate description of the mechanism behind Volcker's disinflation?

**a)** The AD curve probably shifted to the left due to the less restrictive monetary policy, which explains the reduction in the inflation rate between 1979 and 1982.

**b)** Due to the more restrictive monetary policy, the output gap became negative, which explains the increase in the unemployment rate between 1979 and 1982.

**c)** In 1982, it is likely that equilibrium aggregate output was higher than potential, causing the AS curve to shift to the left to eliminate it, which explains the reduction in the unemployment rate and the further decrease in inflation between 1982 and 1986.

**d)** By lowering the Federal Funds Rate, the Federal Reserve accelerated the economy and managed to cut inflation in half in 1982 at the cost of a substantial increase in the unemployment rate, causing a recession.

**e)** None of the above.
"""

# ╔═╡ 20222023-0236-0003-0028-000000000002
@bind q28 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ c2d1b414-105d-4ece-8a56-c1a77711a5a4
md"""
---
"""

# ╔═╡ 20222023-0236-0003-0029-000000000000
md"""
`Yp_shock = `$(@bind Yp_shock Slider(-2.0:0.1:2.0, default=0.0, show_value=true))
"""

# ╔═╡ 20222023-0236-0003-0029-000000000010
let
Ā5 = 5.6 ; λ5 = 0.5 ; m5 = 2.0 ; ϕ5 = 0.3 ; r̄5 = 0.5 # Demand 
γ5 = 4.0 ; Yᴾ5 = 10.0 ; πᵉ5 = 3.0 ; ρ5 = 0.0 ; # Supply 
πd_max5 = (Ā5 / (λ5 * ϕ5)) - r̄5/λ5       # The AD curve y-axis' intercept 
πs_min5 = πᵉ5 - γ5 * (Yᴾ5 + Yp_shock) + ρ5           # The AS curve y-axis' intercept
Y5 = 9.0:0.01:11.0
Y5_ΔĀ5 = 8.0:0.02:15.0
r5 = 0.0:0.005:5.0
 
πd5 = πd_max5 .- ((1 ./(m5 .* ϕ5 .* λ5)) .* Y5) 
πs5 = πs_min5 .+ γ5 .*Y5    
πmp5 = - (r̄5 ./ λ5) .+  r5 ./ λ5

trace9_0 = scatter(; x = [10+Yp_shock,10+Yp_shock], y = [-7,10], mode = "line", line_width = "4", name = "Yp", 
line_color = "Orange")
trace9_1 = scatter(; x = Y5, y = πd5, mode="lines" , line_color = "Blue", line_width = "3",
name  = "AD")
trace9_2 = scatter(; x = Y5, y = πs5, mode="lines" , line_color = "Red", line_width = "3",
name  = "AS")
trace9_3 = scatter(; x = [10.0], y = [3.0], text =["1"], 
textposition = "top center", name ="", mode="markers+text", marker_size= "12",
marker_color="Blue", textcolor = "Black",
textfont = attr(family="sans serif", size=18, color="black")) 
layout9_5 = Layout(;
title_text = "Macroeconomic Equilibrium",
title_x = 0.5,
hovermode = "x",
                    xaxis=attr(title=" GDP trillion dollars (Y)", showgrid=true, zeroline=false),
                    xaxis_range = [9.2, 10.8], 
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
yaxis_range=[-0.0 , 6.0])
   p9_4 = Plot([trace9_0, trace9_1, trace9_2, trace9_3], layout9_5)

trace4_0 = scatter(; x = r5, y = πmp5, mode="lines" , line_color = "Brown", line_width = "3",
name  = "MP") 
trace4_1 = scatter(; x = [2.0], y = [3.0], text =["1"], 
textposition = "top center", name ="", mode="markers+text", 
marker_size= "12", marker_color="Brown", 
textfont = attr(family="sans serif", size=18, color="black"))
layout4_3 = Layout(;
title_text = "MP Curve",
title_x = 0.5,
hovermode = "x",
                xaxis=attr(title=" Real interest rate (r)", showgrid=true, zeroline=false),
                xaxis_range = [0.5, 3.5],
xaxis_tickvals = [1, 1.5, 2, 2.5, 3, 3.5, 4],
                yaxis=attr(title="Rate of inflation (π)", zeroline = false),
yaxis_range=[-0.0 , 6.0]) 
p4_3 = Plot([trace4_0, trace4_1], layout4_3)
[p4_3 p9_4]
end

# ╔═╡ 20222023-0236-0003-0029-000000000001
md"""
The figures above represent the initial macroeconomic equilibrium. Suppose there is a permanent shock to supply, such that potential GDP increases by +0.6 trillion dollars. Using the slider `Yp_shock` to represent this shock, which of the figures below corresponds to the new _long-run_ equilibrium?

**a)** $\pi=2\% \ \  , \ \ Y = 10.3 \ \ , \ \ r=5\% \ \ , \ \ i=3\%$.

**b)** $\pi=1\% \ \  , \ \ Y = 10.6 \ \ , \ \ r=1\% \ \ , \ \ i=2\%$.

**c)** $\pi=3\% \ \  , \ \ Y = 9.7 \ \ , \ \ r=6\% \ \ , \ \ i=10\%$.

**d)** $\pi=4\% \ \  , \ \ Y = 10 \ \ , \ \ r=0\% \ \ , \ \ i=6\%$.

**e)** None of the above.
"""

# ╔═╡ 20222023-0236-0003-0029-000000000002
@bind q29 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 141c66a1-dd4b-4ac8-9401-57a7378f0d25
md"""
---
"""

# ╔═╡ 20222023-0236-0003-0030-000000000000
md"""
`Yp_shockb = `$(@bind Yp_shockb Slider(-2.0:0.1:2.0, default=0.0, show_value=true))
"""

# ╔═╡ 20222023-0236-0003-0030-000000000010
let
Ā5 = 5.6 ; λ5 = 0.5 ; m5 = 2.0 ; ϕ5 = 0.3 ; r̄5 = 0.5 # Demand 
γ5 = 4.0 ; Yᴾ5 = 10.0 ; πᵉ5 = 3.0 ; ρ5 = 0.0 ; # Supply 
πd_max5 = (Ā5 / (λ5 * ϕ5)) - r̄5/λ5       # The AD curve y-axis' intercept 
πs_min5 = πᵉ5 - γ5 * (Yᴾ5 + Yp_shockb) + ρ5           # The AS curve y-axis' intercept
Y5 = 9.0:0.01:11.0
Y5_ΔĀ5 = 8.0:0.02:15.0
r5 = 0.0:0.005:5.0
 
πd5 = πd_max5 .- ((1 ./(m5 .* ϕ5 .* λ5)) .* Y5) 
πs5 = πs_min5 .+ γ5 .*Y5    
πmp5 = - (r̄5 ./ λ5) .+  r5 ./ λ5

trace9_0 = scatter(; x = [10+Yp_shockb,10+Yp_shockb], y = [-7,10], mode = "line", line_width = "4", name = "Yp", 
line_color = "Orange")
trace9_1 = scatter(; x = Y5, y = πd5, mode="lines" , line_color = "Blue", line_width = "3",
name  = "AD")
trace9_2 = scatter(; x = Y5, y = πs5, mode="lines" , line_color = "Red", line_width = "3",
name  = "AS")
trace9_3 = scatter(; x = [10.0], y = [3.0], text =["1"], 
textposition = "top center", name ="", mode="markers+text", marker_size= "12",
marker_color="Blue", textcolor = "Black",
textfont = attr(family="sans serif", size=18, color="black")) 
layout9_5 = Layout(;
title_text = "Macroeconomic Equilibrium",
title_x = 0.5,
hovermode = "x",
                    xaxis=attr(title=" GDP trillion dollars (Y)", showgrid=true, zeroline=false),
                    xaxis_range = [9.2, 10.8], 
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
yaxis_range=[-0.0 , 6.0])
   p9_4 = Plot([trace9_0, trace9_1, trace9_2, trace9_3], layout9_5)

trace4_0 = scatter(; x = r5, y = πmp5, mode="lines" , line_color = "Brown", line_width = "3",
name  = "MP") 
trace4_1 = scatter(; x = [2.0], y = [3.0], text =["1"], 
textposition = "top center", name ="", mode="markers+text", 
marker_size= "12", marker_color="Brown", 
textfont = attr(family="sans serif", size=18, color="black"))
layout4_3 = Layout(;
title_text = "MP Curve",
title_x = 0.5,
hovermode = "x",
                xaxis=attr(title=" Real interest rate (r)", showgrid=true, zeroline=false),
                xaxis_range = [0.5, 3.5],
xaxis_tickvals = [1, 1.5, 2, 2.5, 3, 3.5, 4],
                yaxis=attr(title="Rate of inflation (π)", zeroline = false),
yaxis_range=[-0.0 , 6.0]) 
p4_3 = Plot([trace4_0, trace4_1], layout4_3)
[p4_3 p9_4]
end


# ╔═╡ 20222023-0236-0003-0030-000000000001
md"""
The figures above represent the initial macroeconomic equilibrium. Suppose there is a permanent shock to supply, such that potential GDP decreases by --0.6 trillion dollars. Using the slider `Yp_shockb` to represent this shock, which of the figures below corresponds to the new _short-run_ equilibrium?

**a)** $\pi=4.12\% \ \  , \ \ Y = 9.68 \ \ , \ \ r=2.56\%$.

**b)** $\pi=1\% \ \  , \ \ Y = 10 \ \ , \ \ r=1.7\%$.

**c)** $\pi=2\% \ \  , \ \ Y = 10 \ \ , \ \ r=3.5\%$.

**d)** $\pi=0\% \ \  , \ \ Y = 10\ \ , \ \ r=1.8\%$.

**e)** Nenhuma das anteriores.
"""

# ╔═╡ 20222023-0236-0003-0030-000000000002
@bind q30 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ e514f09f-d5eb-4dcc-bc40-483df518ac4c
md"""
---
"""

# ╔═╡ 20222023-0236-0003-0031-000000000001
md"""
Consider that the economy is in recession. If the self-correcting mechanism has not worked, an easing of monetary policy to promote employment such that $$U=U_n$$ will result in:

**a)** An increase in the inflation rate. 

**b)** A decrease in the inflation rate.

**c)** An increase in potential GDP.

**d)** A decrease in GDP.

**e)** None of the above.
"""

# ╔═╡ 20222023-0236-0003-0031-000000000002
@bind q31 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ a6c509c0-0f40-424f-bf04-21d414fb7782
md"""
---
"""

# ╔═╡ 20222023-0236-0003-0032-000000000001
md"""
According to the Taylor Rule, suppose inflation is equal to target inflation and GDP is above potential GDP. A Central Bank with the primary objective of price stability should:

**a)** Do nothing, because inflation cannot rise when unemployment is reduced.

**b)** Restrict monetary policy to avoid a rise in the inflation rate.

**c)** Do nothing, because stabilizing economic activity is not the main objective.

**d)** Easing monetary policy, because avoiding low unemployment rates is more important than avoiding low inflation rates.

**e)** None of the above.
"""

# ╔═╡ 20222023-0236-0003-0032-000000000002
@bind q32 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ d22481a4-9808-4704-bd68-cb77bc5b9d7c
md"""
---
"""

# ╔═╡ 20222023-0236-0003-0033-000000000001
md"""
If the target inflation rate is equal to 2%, current inflation is equal to 2%, and the output gap is equal to zero, then according to the Taylor rule (different from the Taylor Principle), the Fed Funds rate should be:

**a)** 0.0%

**b)** 2%

**c)** 4%

**d)** 3%

**e)** There is not enough information to answer the question.
"""

# ╔═╡ 20222023-0236-0003-0033-000000000002
@bind q33 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 1edac556-b332-483b-a1fa-141121ec7126
md"""
---
"""

# ╔═╡ 20222023-0236-0003-0034-000000000001
md"""
Quantitative easing (one of the types of unconventional monetary policy) consists of:

**a)** Buying variable-yield financial assets.

**b)** Buying short-maturity assets.

**c)** Buying low-risk assets.

**d)** Buying a reduced quantity of assets.

**e)** None of the above.
"""

# ╔═╡ 20222023-0236-0003-0034-000000000002
@bind q34 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 7a823207-4466-422b-8758-8d8ac83543d9
md"""
---
"""

# ╔═╡ 20222023-0236-0003-0035-000000000001
md"""
"The ECB considers that the best way to maintain price stability is to aim for inflation of $2\%$ ("target"). This objective is _symmetric_, which means that negative and positive deviations of inflation from the target are equally undesirable." Why did the ECB change its policy from a "ceiling" to "symmetrical deviations"?

**a)** Because, otherwise, the inflation rate in the Eurozone would always tend to be below $2\%$.

**b)** Because the ECB, not knowing quite what to do, decided to do so.

**c)** Because the European Commission decided so.

**d)** Because, otherwise, the inflation rate in the Eurozone would always tend to be above $2\%$.

**e)** None of the above.
"""

# ╔═╡ 20222023-0236-0003-0035-000000000002
@bind q35 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 0bacb266-e7a9-4f3c-95da-730a43521bf3
md"""
---
"""

# ╔═╡ 20222023-0236-0003-0036-000000000001
md"""
Up to the ZLB (Zero Lower Bound), the MP curve and the AD curve have their normal representation. After the ZLB is reached:

**a)** The MP curve becomes positive.

**b)** The MP curve becomes negative.

**c)** The AD curve becomes negative.

**d)** The MP and AD curves now have the same slope.

**e)** None of the above.
"""

# ╔═╡ 20222023-0236-0003-0036-000000000002
@bind q36 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ f841871c-f733-409b-82b3-a0609f14d8e1
md"""
---
"""

# ╔═╡ bb4a77e6-916c-4d8a-b834-6a36fef20e6f
html"""
<img src="https://vivaldomendes.org/images/Tests/multiplier1.png" style="width:600px" />
"""

# ╔═╡ 20222023-0236-0003-0037-000000000001
md"""
The figure above shows three different situations regarding the value of the fiscal multiplier. Which is the situation in which the fiscal multiplier is the highest?

**a)** Case 3.

**b)** Case 0.

**c)** Case 1.

**d)** Case 2.

**e)** None of the above.
"""

# ╔═╡ 20222023-0236-0003-0037-000000000002
@bind q37 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 15e00bf4-b1a4-41db-a403-fb69b58d12c3
md"""
---
"""

# ╔═╡ 20222023-0236-0003-0038-000000000001
md"""
There are arguments that public debt is a "burden". Select the option that supports this position.

**a)** Public capital (highways, schools, among others) increases the future productivity of the economy.

**b)** High levels of education and better health increase labor productivity.

**c)** Public capital and human capital promote positive externalities that increase future productivity and lead to higher income and tax revenue.

**d)** Increased public debt requires increased taxes which produce distortions in the allocation of investment funds and work effort.

**e)** None of the above.
"""

# ╔═╡ 20222023-0236-0003-0038-000000000002
@bind q38 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 76a66aed-8337-4f05-ae43-a36182da4954
md"""
---
"""

# ╔═╡ 20222023-0236-0003-0039-000000000001
md"""
Much of the combined growth in spending on Social Security and the main health programs in the US is the result of:

**a)** Unemployment rate growth.

**b)** Growth in the employment rate.

**c)** Growth in the working population.

**d)** An aging population.

**e)** None of the above.
"""

# ╔═╡ 20222023-0236-0003-0039-000000000002
@bind q39 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ d7781804-b765-4ee9-b7b4-cd15e7d318d6
md"""
---
"""

# ╔═╡ 20222023-0236-0003-0040-000000000001
md"""
Consider that the growth rate of real GDP is given by $g$, that the real interest rate paid on public debt is given by $r_p$ and that the government's primary balance is negative. Select the correct option.

**a)** If $g>r_p$ , the level of public debt is unsustainable.

**b)** If $g=r_p$ , the level of public debt is sustainable.

**c)** If $g<r_p$ , the level of public debt is unsustainable.

**d)** $g$ and $r_p$ have little to do with the sustainability of public debt.

**e)** None of the above.
"""


# ╔═╡ 20222023-0236-0003-0040-000000000002
@bind q40 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ a868f533-c016-49bc-83bd-3c992bc764c8
md"""
---
"""

# ╔═╡ 4d9a23a3-dccd-42e3-af0a-1f1f1f8cc73b
md"""
!!! danger "Final instructions"

	You have completed the test.

	The last step is to confirm that you want to **save your answers**, using the **Checkbox after this box**. When you click, a `.csv` file will be generated in the same folder as this Notebook.

	**This is the file you need to send to the teaching team.**

	Before sending, make sure that the date/time in the file makes sense. **Only then should you close the Notebook.**
"""

# ╔═╡ 9f2fdf90-9194-47ab-b7c1-b00d765920a4
md"
I confirm that throughout the test, I have always proceeded in accordance with all the **standards of academic ethics and integrity**, that is, without any illicit recourse in the light of ISCTE rules and, in particular, of the Macroeconomics Curricular Unit, so I want to **save my answers** in order to send them to the teaching team for my work to be appropriately evaluated.
$(CheckBox(default=false))
"

# ╔═╡ 51fea41d-0689-4472-80f8-a400f7c999fe
md"## Células auxiliares"

# ╔═╡ 852b8a1e-ee2f-4ff0-b6a1-82c85abb4299
md"### Packages"

# ╔═╡ 433e93a2-492f-4931-9418-20f1296f3051
md"### CSS code"

# ╔═╡ 20222023-0236-0003-0000-000000000002
html"""
<link href="https://fonts.googleapis.com/css?family=Montserrat:300,300italic,700,700italic" rel="stylesheet">

<style>
	main {
		max-width: 1200px;
		padding: 5%;
        display:block;
        margin-left: auto;
        margin-right: auto;
	}
	pluto-output {
		font-family: "Montserrat" !important;
		font-size: 1em;
		line-height: 1.5;
	}
	.plutoui-toc {
		font-family: "Montserrat" !important;
		font-size: 90%;
	}
	.admonition-title {
		font-family: "Montserrat" !important;
	}
	pluto-output h1, h2, h3 {
		font-family: "Montserrat" !important;
		border: none !important;
	}
	pluto-output h1 {
		font-size: 1.8em !important;
		margin-top: 1.5em;
		margin-bottom: 0.5em;
	}
	pluto-output h2 {
		font-size: 1.5em !important;
		margin-top: 1.8em;
		margin-bottom: 1em;
	}
	pluto-output h3 {
		font-size: 1.3em !important;
		margin-top: 1.5em;
		margin-bottom: 1em;
	}
	img:not(picture *) {
		width: 80%;
		display: block;
		margin-left: auto;
		margin-right: auto;
	}
	title {
		font-size: 2.2em;
		display: block;
		font-weight: bold;
		text-align: left;
		margin: 1.5em 0 0em 0;
}
	subtitle {
		font-size: 1.6em;
		display: block;
		text-align: left;
		margin: 0 0 1.5em 0;
}
	author {
		display: block;
		text-align: left;
		padding-bottom: 0.8em;
		border-bottom: 3px solid !important;
}
	email {
		display: block;
		text-align: left;
		margin: 0 0 2.5em 0;
}
	semester {
		font-size: 1.3em;
		display: block;
		text-align: left;
		margin: 0 0 1.5em 0;
}
	.admonition-title {
		font-size: 125%;
	}
	ol {
		list-style-type: lower-alpha;
	}
	li::marker {
		font-weight: bold;
	}
	li {
		margin-top: 1em !important;
		margin-bottom: 1em !important;
	}
	.small {
		font-size: 80%;
	}
	.centered-image {
		display: block;
		margin-left: auto;
		margin-right: auto;
		margin-top: 1em;
		margin-bottom: 1em;
		width: 90%;
	}
	details {
		font-size: 80%;
		margin-left: 3em;
	}
	summary {
		font-size: 125%;
		margin-left: -2.2em;
		margin-top: 0.5em;
		margin-bottom: 0.5em;
	}
	input[type="checkbox"] {
		transform: scale(1.5);
	}
	textarea, input[type="text"] {
		font-family: "Montserrat" !important;
		font-size: 0.85em !important;
		line-height: 1.5;
	}
    pluto-cell>button,pluto-input>button,pluto-shoulder {
    display: none !important;
    }
</style>
"""

# ╔═╡ bdf49d4c-985d-457e-b31f-7aab9a17552c
md"### Internal functions"

# ╔═╡ 20222023-0236-0003-0000-000000000001
function tchanã(ans::Union{Nothing,String},correct::String)	
	if typeof(ans) == Nothing
		md"""
		👆 *Please select one answer.*
		"""
	else
		if ans == correct
			md"""
			!!! tip "🎉 Correct answer!"
			"""
		else	
			md"""
			!!! danger "👎 Wrong answer"
				
				Try again. **But study first!!!** 😡
			"""
		end
	end
end;

# ╔═╡ 20222023-0236-0003-0001-000000000003
tchanã(q01,"a)")

# ╔═╡ 20222023-0236-0003-0002-000000000003
tchanã(q02,"c)")

# ╔═╡ 20222023-0236-0003-0003-000000000003
tchanã(q03,"c)")

# ╔═╡ 20222023-0236-0003-0004-000000000003
tchanã(q04,"e)")

# ╔═╡ 20222023-0236-0003-0005-000000000003
tchanã(q05,"b)")

# ╔═╡ 20222023-0236-0003-0006-000000000003
tchanã(q06,"a)")

# ╔═╡ 20222023-0236-0003-0007-000000000003
tchanã(q07,"d)")

# ╔═╡ 20222023-0236-0003-0008-000000000003
tchanã(q08,"c)")

# ╔═╡ 20222023-0236-0003-0009-000000000003
tchanã(q09,"b)")

# ╔═╡ 20222023-0236-0003-0010-000000000003
tchanã(q10,"b)")

# ╔═╡ 20222023-0236-0003-0011-000000000003
tchanã(q11,"a)")

# ╔═╡ 20222023-0236-0003-0012-000000000003
tchanã(q12,"b)")

# ╔═╡ 20222023-0236-0003-0013-000000000003
tchanã(q13,"a)")

# ╔═╡ 20222023-0236-0003-0014-000000000003
tchanã(q14,"e)")

# ╔═╡ 20222023-0236-0003-0015-000000000003
tchanã(q15,"d)")

# ╔═╡ 20222023-0236-0003-0016-000000000003
tchanã(q16,"a)")

# ╔═╡ 20222023-0236-0003-0017-000000000003
tchanã(q17,"a)")

# ╔═╡ 20222023-0236-0003-0018-000000000003
tchanã(q18,"e)")

# ╔═╡ 20222023-0236-0003-0019-000000000003
tchanã(q19,"c)")

# ╔═╡ 20222023-0236-0003-0020-000000000003
tchanã(q20,"a)")

# ╔═╡ 20222023-0236-0003-0021-000000000003
tchanã(q21,"d)")

# ╔═╡ 20222023-0236-0003-0022-000000000003
tchanã(q22,"a)")

# ╔═╡ 20222023-0236-0003-0023-000000000003
tchanã(q23,"d)")

# ╔═╡ 20222023-0236-0003-0024-000000000003
tchanã(q24,"a)")

# ╔═╡ 20222023-0236-0003-0025-000000000003
tchanã(q25,"a)")

# ╔═╡ 20222023-0236-0003-0026-000000000003
tchanã(q26,"e)")

# ╔═╡ 20222023-0236-0003-0027-000000000003
tchanã(q27,"b)")

# ╔═╡ 20222023-0236-0003-0028-000000000003
tchanã(q28,"b)")

# ╔═╡ 20222023-0236-0003-0029-000000000003
tchanã(q29,"b)")

# ╔═╡ 20222023-0236-0003-0030-000000000003
tchanã(q30,"a)")

# ╔═╡ 20222023-0236-0003-0031-000000000003
tchanã(q31,"a)")

# ╔═╡ 20222023-0236-0003-0032-000000000003
tchanã(q32,"b)")

# ╔═╡ 20222023-0236-0003-0033-000000000003
tchanã(q33,"e)")

# ╔═╡ 20222023-0236-0003-0034-000000000003
tchanã(q34,"e)")

# ╔═╡ 20222023-0236-0003-0035-000000000003
tchanã(q35,"a)")

# ╔═╡ 20222023-0236-0003-0036-000000000003
tchanã(q36,"b)")

# ╔═╡ 20222023-0236-0003-0037-000000000003
tchanã(q37,"a)")

# ╔═╡ 20222023-0236-0003-0038-000000000003
tchanã(q38,"d)")

# ╔═╡ 20222023-0236-0003-0039-000000000003
tchanã(q39,"d)")

# ╔═╡ 20222023-0236-0003-0040-000000000003
tchanã(q40,"c)")



# ╔═╡ 00000000-0000-0000-0000-000000000001
PLUTO_PROJECT_TOML_CONTENTS = """
[deps]
CSV = "336ed68f-0bac-5ca0-87d4-7b16caf5d00b"
DataFrames = "a93c6f00-e57d-5684-b7b6-d8193f3e46c0"
Dates = "ade2ca70-3891-5945-98fb-dc099432e06a"
HypertextLiteral = "ac1192a8-f4b3-4bfe-ba22-af5b92cd3ab2"
PeriodicalDates = "276e7ca9-e0d7-440b-97bc-a6ae82f545b1"
PlotlyBase = "a03496cd-edff-5a9b-9e67-9cda94a718b5"
PlutoTeachingTools = "661c6b06-c737-4d37-b85c-46df65de6f69"
PlutoUI = "7f904dfe-b85e-4ff6-b463-dae2292396a8"
StatsBase = "2913bbd2-ae8a-5f71-8c99-4fb6c76f3a91"

[compat]
CSV = "~0.10.10"
DataFrames = "~1.5.0"
HypertextLiteral = "~0.9.4"
PeriodicalDates = "~2.0.0"
PlotlyBase = "~0.8.19"
PlutoTeachingTools = "~0.2.11"
PlutoUI = "~0.7.51"
StatsBase = "~0.34.0"
"""

# ╔═╡ 00000000-0000-0000-0000-000000000002
PLUTO_MANIFEST_TOML_CONTENTS = """
# This file is machine-generated - editing it directly is not advised

julia_version = "1.9.3"
manifest_format = "2.0"
project_hash = "7844394d0b300f9e0571a750b51d08b1e8c515de"

[[deps.AbstractPlutoDingetjes]]
deps = ["Pkg"]
git-tree-sha1 = "91bd53c39b9cbfb5ef4b015e8b582d344532bd0a"
uuid = "6e696c72-6542-2067-7265-42206c756150"
version = "1.2.0"

[[deps.ArgTools]]
uuid = "0dad84c5-d112-42e6-8d28-ef12dabb789f"
version = "1.1.1"

[[deps.Artifacts]]
uuid = "56f22d72-fd6d-98f1-02f0-08ddc0907c33"

[[deps.Base64]]
uuid = "2a0f44e3-6c83-55bd-87e4-b1978d98bd5f"

[[deps.CSV]]
deps = ["CodecZlib", "Dates", "FilePathsBase", "InlineStrings", "Mmap", "Parsers", "PooledArrays", "PrecompileTools", "SentinelArrays", "Tables", "Unicode", "WeakRefStrings", "WorkerUtilities"]
git-tree-sha1 = "44dbf560808d49041989b8a96cae4cffbeb7966a"
uuid = "336ed68f-0bac-5ca0-87d4-7b16caf5d00b"
version = "0.10.11"

[[deps.CodeTracking]]
deps = ["InteractiveUtils", "UUIDs"]
git-tree-sha1 = "a1296f0fe01a4c3f9bf0dc2934efbf4416f5db31"
uuid = "da1fd8a2-8d9e-5ec2-8556-3022fb5608a2"
version = "1.3.4"

[[deps.CodecZlib]]
deps = ["TranscodingStreams", "Zlib_jll"]
git-tree-sha1 = "02aa26a4cf76381be7f66e020a3eddeb27b0a092"
uuid = "944b1d66-785c-5afd-91f1-9de20f533193"
version = "0.7.2"

[[deps.ColorSchemes]]
deps = ["ColorTypes", "ColorVectorSpace", "Colors", "FixedPointNumbers", "PrecompileTools", "Random"]
git-tree-sha1 = "d9a8f86737b665e15a9641ecbac64deef9ce6724"
uuid = "35d6a980-a343-548e-a6ea-1d62b119f2f4"
version = "3.23.0"

[[deps.ColorTypes]]
deps = ["FixedPointNumbers", "Random"]
git-tree-sha1 = "eb7f0f8307f71fac7c606984ea5fb2817275d6e4"
uuid = "3da002f7-5984-5a60-b8a6-cbb66c0b333f"
version = "0.11.4"

[[deps.ColorVectorSpace]]
deps = ["ColorTypes", "FixedPointNumbers", "LinearAlgebra", "Requires", "Statistics", "TensorCore"]
git-tree-sha1 = "a1f44953f2382ebb937d60dafbe2deea4bd23249"
uuid = "c3611d14-8923-5661-9e6a-0046d554d3a4"
version = "0.10.0"

    [deps.ColorVectorSpace.extensions]
    SpecialFunctionsExt = "SpecialFunctions"

    [deps.ColorVectorSpace.weakdeps]
    SpecialFunctions = "276daf66-3868-5448-9aa4-cd146d93841b"

[[deps.Colors]]
deps = ["ColorTypes", "FixedPointNumbers", "Reexport"]
git-tree-sha1 = "fc08e5930ee9a4e03f84bfb5211cb54e7769758a"
uuid = "5ae59095-9a9b-59fe-a467-6f913c188581"
version = "0.12.10"

[[deps.Compat]]
deps = ["UUIDs"]
git-tree-sha1 = "e460f044ca8b99be31d35fe54fc33a5c33dd8ed7"
uuid = "34da2185-b29b-5c13-b0c7-acf172513d20"
version = "4.9.0"
weakdeps = ["Dates", "LinearAlgebra"]

    [deps.Compat.extensions]
    CompatLinearAlgebraExt = "LinearAlgebra"

[[deps.CompilerSupportLibraries_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "e66e0078-7015-5450-92f7-15fbd957f2ae"
version = "1.0.5+0"

[[deps.Crayons]]
git-tree-sha1 = "249fe38abf76d48563e2f4556bebd215aa317e15"
uuid = "a8cc5b0e-0ffa-5ad4-8c14-923d3ee1735f"
version = "4.1.1"

[[deps.DataAPI]]
git-tree-sha1 = "8da84edb865b0b5b0100c0666a9bc9a0b71c553c"
uuid = "9a962f9c-6df0-11e9-0e5d-c546b8b5ee8a"
version = "1.15.0"

[[deps.DataFrames]]
deps = ["Compat", "DataAPI", "Future", "InlineStrings", "InvertedIndices", "IteratorInterfaceExtensions", "LinearAlgebra", "Markdown", "Missings", "PooledArrays", "PrettyTables", "Printf", "REPL", "Random", "Reexport", "SentinelArrays", "SnoopPrecompile", "SortingAlgorithms", "Statistics", "TableTraits", "Tables", "Unicode"]
git-tree-sha1 = "aa51303df86f8626a962fccb878430cdb0a97eee"
uuid = "a93c6f00-e57d-5684-b7b6-d8193f3e46c0"
version = "1.5.0"

[[deps.DataStructures]]
deps = ["Compat", "InteractiveUtils", "OrderedCollections"]
git-tree-sha1 = "3dbd312d370723b6bb43ba9d02fc36abade4518d"
uuid = "864edb3b-99cc-5e75-8d2d-829cb0a9cfe8"
version = "0.18.15"

[[deps.DataValueInterfaces]]
git-tree-sha1 = "bfc1187b79289637fa0ef6d4436ebdfe6905cbd6"
uuid = "e2d170a0-9d28-54be-80f0-106bbe20a464"
version = "1.0.0"

[[deps.Dates]]
deps = ["Printf"]
uuid = "ade2ca70-3891-5945-98fb-dc099432e06a"

[[deps.DelimitedFiles]]
deps = ["Mmap"]
git-tree-sha1 = "9e2f36d3c96a820c678f2f1f1782582fcf685bae"
uuid = "8bb1440f-4735-579b-a4ab-409b98df4dab"
version = "1.9.1"

[[deps.Distributed]]
deps = ["Random", "Serialization", "Sockets"]
uuid = "8ba89e20-285c-5b6f-9357-94700520ee1b"

[[deps.DocStringExtensions]]
deps = ["LibGit2"]
git-tree-sha1 = "2fb1e02f2b635d0845df5d7c167fec4dd739b00d"
uuid = "ffbed154-4ef7-542d-bbb7-c09d3a79fcae"
version = "0.9.3"

[[deps.Downloads]]
deps = ["ArgTools", "FileWatching", "LibCURL", "NetworkOptions"]
uuid = "f43a241f-c20a-4ad4-852c-f6b1247861c6"
version = "1.6.0"

[[deps.FilePathsBase]]
deps = ["Compat", "Dates", "Mmap", "Printf", "Test", "UUIDs"]
git-tree-sha1 = "e27c4ebe80e8699540f2d6c805cc12203b614f12"
uuid = "48062228-2e41-5def-b9a4-89aafe57970f"
version = "0.9.20"

[[deps.FileWatching]]
uuid = "7b1f6079-737a-58dc-b8bc-7a2ca5c1b5ee"

[[deps.FixedPointNumbers]]
deps = ["Statistics"]
git-tree-sha1 = "335bfdceacc84c5cdf16aadc768aa5ddfc5383cc"
uuid = "53c48c17-4a7d-5ca2-90c5-79b7896eea93"
version = "0.8.4"

[[deps.Formatting]]
deps = ["Printf"]
git-tree-sha1 = "8339d61043228fdd3eb658d86c926cb282ae72a8"
uuid = "59287772-0a20-5a39-b81b-1366585eb4c0"
version = "0.4.2"

[[deps.Future]]
deps = ["Random"]
uuid = "9fa8497b-333b-5362-9e8d-4d0656e87820"

[[deps.Hyperscript]]
deps = ["Test"]
git-tree-sha1 = "8d511d5b81240fc8e6802386302675bdf47737b9"
uuid = "47d2ed2b-36de-50cf-bf87-49c2cf4b8b91"
version = "0.0.4"

[[deps.HypertextLiteral]]
deps = ["Tricks"]
git-tree-sha1 = "c47c5fa4c5308f27ccaac35504858d8914e102f9"
uuid = "ac1192a8-f4b3-4bfe-ba22-af5b92cd3ab2"
version = "0.9.4"

[[deps.IOCapture]]
deps = ["Logging", "Random"]
git-tree-sha1 = "d75853a0bdbfb1ac815478bacd89cd27b550ace6"
uuid = "b5f81e59-6552-4d32-b1f0-c071b021bf89"
version = "0.2.3"

[[deps.InlineStrings]]
deps = ["Parsers"]
git-tree-sha1 = "9cc2baf75c6d09f9da536ddf58eb2f29dedaf461"
uuid = "842dd82b-1e85-43dc-bf29-5d0ee9dffc48"
version = "1.4.0"

[[deps.InteractiveUtils]]
deps = ["Markdown"]
uuid = "b77e0a4c-d291-57a0-90e8-8db25a27a240"

[[deps.InvertedIndices]]
git-tree-sha1 = "0dc7b50b8d436461be01300fd8cd45aa0274b038"
uuid = "41ab1584-1d38-5bbf-9106-f11c6c58b48f"
version = "1.3.0"

[[deps.IrrationalConstants]]
git-tree-sha1 = "630b497eafcc20001bba38a4651b327dcfc491d2"
uuid = "92d709cd-6900-40b7-9082-c6be49f344b6"
version = "0.2.2"

[[deps.IteratorInterfaceExtensions]]
git-tree-sha1 = "a3f24677c21f5bbe9d2a714f95dcd58337fb2856"
uuid = "82899510-4779-5014-852e-03e436cf321d"
version = "1.0.0"

[[deps.JSON]]
deps = ["Dates", "Mmap", "Parsers", "Unicode"]
git-tree-sha1 = "31e996f0a15c7b280ba9f76636b3ff9e2ae58c9a"
uuid = "682c06a0-de6a-54ab-a142-c8b1cf79cde6"
version = "0.21.4"

[[deps.JuliaInterpreter]]
deps = ["CodeTracking", "InteractiveUtils", "Random", "UUIDs"]
git-tree-sha1 = "81dc6aefcbe7421bd62cb6ca0e700779330acff8"
uuid = "aa1ae85d-cabe-5617-a682-6adf51b2e16a"
version = "0.9.25"

[[deps.LaTeXStrings]]
git-tree-sha1 = "f2355693d6778a178ade15952b7ac47a4ff97996"
uuid = "b964fa9f-0449-5b57-a5c2-d3ea65f4040f"
version = "1.3.0"

[[deps.Latexify]]
deps = ["Formatting", "InteractiveUtils", "LaTeXStrings", "MacroTools", "Markdown", "OrderedCollections", "Printf", "Requires"]
git-tree-sha1 = "f428ae552340899a935973270b8d98e5a31c49fe"
uuid = "23fbe1c1-3f47-55db-b15f-69d7ec21a316"
version = "0.16.1"

    [deps.Latexify.extensions]
    DataFramesExt = "DataFrames"
    SymEngineExt = "SymEngine"

    [deps.Latexify.weakdeps]
    DataFrames = "a93c6f00-e57d-5684-b7b6-d8193f3e46c0"
    SymEngine = "123dc426-2d89-5057-bbad-38513e3affd8"

[[deps.LibCURL]]
deps = ["LibCURL_jll", "MozillaCACerts_jll"]
uuid = "b27032c2-a3e7-50c8-80cd-2d36dbcbfd21"
version = "0.6.3"

[[deps.LibCURL_jll]]
deps = ["Artifacts", "LibSSH2_jll", "Libdl", "MbedTLS_jll", "Zlib_jll", "nghttp2_jll"]
uuid = "deac9b47-8bc7-5906-a0fe-35ac56dc84c0"
version = "7.84.0+0"

[[deps.LibGit2]]
deps = ["Base64", "NetworkOptions", "Printf", "SHA"]
uuid = "76f85450-5226-5b5a-8eaa-529ad045b433"

[[deps.LibSSH2_jll]]
deps = ["Artifacts", "Libdl", "MbedTLS_jll"]
uuid = "29816b5a-b9ab-546f-933c-edad1886dfa8"
version = "1.10.2+0"

[[deps.Libdl]]
uuid = "8f399da3-3557-5675-b5ff-fb832c97cbdb"

[[deps.LinearAlgebra]]
deps = ["Libdl", "OpenBLAS_jll", "libblastrampoline_jll"]
uuid = "37e2e46d-f89d-539d-b4ee-838fcccc9c8e"

[[deps.LogExpFunctions]]
deps = ["DocStringExtensions", "IrrationalConstants", "LinearAlgebra"]
git-tree-sha1 = "7d6dd4e9212aebaeed356de34ccf262a3cd415aa"
uuid = "2ab3a3ac-af41-5b50-aa03-7779005ae688"
version = "0.3.26"

    [deps.LogExpFunctions.extensions]
    LogExpFunctionsChainRulesCoreExt = "ChainRulesCore"
    LogExpFunctionsChangesOfVariablesExt = "ChangesOfVariables"
    LogExpFunctionsInverseFunctionsExt = "InverseFunctions"

    [deps.LogExpFunctions.weakdeps]
    ChainRulesCore = "d360d2e6-b24c-11e9-a2a3-2a2ae2dbcce4"
    ChangesOfVariables = "9e997f8a-9a97-42d5-a9f1-ce6bfc15e2c0"
    InverseFunctions = "3587e190-3f89-42d0-90ee-14403ec27112"

[[deps.Logging]]
uuid = "56ddb016-857b-54e1-b83d-db4d58db5568"

[[deps.LoweredCodeUtils]]
deps = ["JuliaInterpreter"]
git-tree-sha1 = "60168780555f3e663c536500aa790b6368adc02a"
uuid = "6f1432cf-f94c-5a45-995e-cdbf5db27b0b"
version = "2.3.0"

[[deps.MIMEs]]
git-tree-sha1 = "65f28ad4b594aebe22157d6fac869786a255b7eb"
uuid = "6c6e2e6c-3030-632d-7369-2d6c69616d65"
version = "0.1.4"

[[deps.MacroTools]]
deps = ["Markdown", "Random"]
git-tree-sha1 = "9ee1618cbf5240e6d4e0371d6f24065083f60c48"
uuid = "1914dd2f-81c6-5fcd-8719-6d5c9610ff09"
version = "0.5.11"

[[deps.Markdown]]
deps = ["Base64"]
uuid = "d6f4376e-aef5-505a-96c1-9c027394607a"

[[deps.MbedTLS_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "c8ffd9c3-330d-5841-b78e-0817d7145fa1"
version = "2.28.2+0"

[[deps.Missings]]
deps = ["DataAPI"]
git-tree-sha1 = "f66bdc5de519e8f8ae43bdc598782d35a25b1272"
uuid = "e1d29d7a-bbdc-5cf2-9ac0-f12de2c33e28"
version = "1.1.0"

[[deps.Mmap]]
uuid = "a63ad114-7e13-5084-954f-fe012c677804"

[[deps.MozillaCACerts_jll]]
uuid = "14a3606d-f60d-562e-9121-12d972cd8159"
version = "2022.10.11"

[[deps.NetworkOptions]]
uuid = "ca575930-c2e3-43a9-ace4-1e988b2c1908"
version = "1.2.0"

[[deps.OpenBLAS_jll]]
deps = ["Artifacts", "CompilerSupportLibraries_jll", "Libdl"]
uuid = "4536629a-c528-5b80-bd46-f80d51c5b363"
version = "0.3.21+4"

[[deps.OrderedCollections]]
git-tree-sha1 = "2e73fe17cac3c62ad1aebe70d44c963c3cfdc3e3"
uuid = "bac558e1-5e72-5ebc-8fee-abe8a469f55d"
version = "1.6.2"

[[deps.Parameters]]
deps = ["OrderedCollections", "UnPack"]
git-tree-sha1 = "34c0e9ad262e5f7fc75b10a9952ca7692cfc5fbe"
uuid = "d96e819e-fc66-5662-9728-84c9c7592b0a"
version = "0.12.3"

[[deps.Parsers]]
deps = ["Dates", "PrecompileTools", "UUIDs"]
git-tree-sha1 = "716e24b21538abc91f6205fd1d8363f39b442851"
uuid = "69de0a69-1ddd-5017-9359-2bf0b02dc9f0"
version = "2.7.2"

[[deps.PeriodicalDates]]
deps = ["Dates", "Printf", "RecipesBase"]
git-tree-sha1 = "e616941f8093e50a373e7d51875143213f82eca4"
uuid = "276e7ca9-e0d7-440b-97bc-a6ae82f545b1"
version = "2.0.0"

[[deps.Pkg]]
deps = ["Artifacts", "Dates", "Downloads", "FileWatching", "LibGit2", "Libdl", "Logging", "Markdown", "Printf", "REPL", "Random", "SHA", "Serialization", "TOML", "Tar", "UUIDs", "p7zip_jll"]
uuid = "44cfe95a-1eb2-52ea-b672-e2afdf69b78f"
version = "1.9.2"

[[deps.PlotlyBase]]
deps = ["ColorSchemes", "Dates", "DelimitedFiles", "DocStringExtensions", "JSON", "LaTeXStrings", "Logging", "Parameters", "Pkg", "REPL", "Requires", "Statistics", "UUIDs"]
git-tree-sha1 = "56baf69781fc5e61607c3e46227ab17f7040ffa2"
uuid = "a03496cd-edff-5a9b-9e67-9cda94a718b5"
version = "0.8.19"

[[deps.PlutoHooks]]
deps = ["InteractiveUtils", "Markdown", "UUIDs"]
git-tree-sha1 = "072cdf20c9b0507fdd977d7d246d90030609674b"
uuid = "0ff47ea0-7a50-410d-8455-4348d5de0774"
version = "0.0.5"

[[deps.PlutoLinks]]
deps = ["FileWatching", "InteractiveUtils", "Markdown", "PlutoHooks", "Revise", "UUIDs"]
git-tree-sha1 = "8f5fa7056e6dcfb23ac5211de38e6c03f6367794"
uuid = "0ff47ea0-7a50-410d-8455-4348d5de0420"
version = "0.1.6"

[[deps.PlutoTeachingTools]]
deps = ["Downloads", "HypertextLiteral", "LaTeXStrings", "Latexify", "Markdown", "PlutoLinks", "PlutoUI", "Random"]
git-tree-sha1 = "542de5acb35585afcf202a6d3361b430bc1c3fbd"
uuid = "661c6b06-c737-4d37-b85c-46df65de6f69"
version = "0.2.13"

[[deps.PlutoUI]]
deps = ["AbstractPlutoDingetjes", "Base64", "ColorTypes", "Dates", "FixedPointNumbers", "Hyperscript", "HypertextLiteral", "IOCapture", "InteractiveUtils", "JSON", "Logging", "MIMEs", "Markdown", "Random", "Reexport", "URIs", "UUIDs"]
git-tree-sha1 = "e47cd150dbe0443c3a3651bc5b9cbd5576ab75b7"
uuid = "7f904dfe-b85e-4ff6-b463-dae2292396a8"
version = "0.7.52"

[[deps.PooledArrays]]
deps = ["DataAPI", "Future"]
git-tree-sha1 = "a6062fe4063cdafe78f4a0a81cfffb89721b30e7"
uuid = "2dfb63ee-cc39-5dd5-95bd-886bf059d720"
version = "1.4.2"

[[deps.PrecompileTools]]
deps = ["Preferences"]
git-tree-sha1 = "03b4c25b43cb84cee5c90aa9b5ea0a78fd848d2f"
uuid = "aea7be01-6a6a-4083-8856-8a6e6704d82a"
version = "1.2.0"

[[deps.Preferences]]
deps = ["TOML"]
git-tree-sha1 = "7eb1686b4f04b82f96ed7a4ea5890a4f0c7a09f1"
uuid = "21216c6a-2e73-6563-6e65-726566657250"
version = "1.4.0"

[[deps.PrettyTables]]
deps = ["Crayons", "LaTeXStrings", "Markdown", "Printf", "Reexport", "StringManipulation", "Tables"]
git-tree-sha1 = "ee094908d720185ddbdc58dbe0c1cbe35453ec7a"
uuid = "08abe8d2-0d0c-5749-adfa-8a2ac140af0d"
version = "2.2.7"

[[deps.Printf]]
deps = ["Unicode"]
uuid = "de0858da-6303-5e67-8744-51eddeeeb8d7"

[[deps.REPL]]
deps = ["InteractiveUtils", "Markdown", "Sockets", "Unicode"]
uuid = "3fa0cd96-eef1-5676-8a61-b3b8758bbffb"

[[deps.Random]]
deps = ["SHA", "Serialization"]
uuid = "9a3f8284-a2c9-5f02-9a11-845980a1fd5c"

[[deps.RecipesBase]]
deps = ["PrecompileTools"]
git-tree-sha1 = "5c3d09cc4f31f5fc6af001c250bf1278733100ff"
uuid = "3cdcf5f2-1ef4-517c-9805-6587b60abb01"
version = "1.3.4"

[[deps.Reexport]]
git-tree-sha1 = "45e428421666073eab6f2da5c9d310d99bb12f9b"
uuid = "189a3867-3050-52da-a836-e630ba90ab69"
version = "1.2.2"

[[deps.Requires]]
deps = ["UUIDs"]
git-tree-sha1 = "838a3a4188e2ded87a4f9f184b4b0d78a1e91cb7"
uuid = "ae029012-a4dd-5104-9daa-d747884805df"
version = "1.3.0"

[[deps.Revise]]
deps = ["CodeTracking", "Distributed", "FileWatching", "JuliaInterpreter", "LibGit2", "LoweredCodeUtils", "OrderedCollections", "Pkg", "REPL", "Requires", "UUIDs", "Unicode"]
git-tree-sha1 = "1e597b93700fa4045d7189afa7c004e0584ea548"
uuid = "295af30f-e4ad-537b-8983-00126c2a3abe"
version = "3.5.3"

[[deps.SHA]]
uuid = "ea8e919c-243c-51af-8825-aaa63cd721ce"
version = "0.7.0"

[[deps.SentinelArrays]]
deps = ["Dates", "Random"]
git-tree-sha1 = "04bdff0b09c65ff3e06a05e3eb7b120223da3d39"
uuid = "91c51154-3ec4-41a3-a24f-3f23e20d615c"
version = "1.4.0"

[[deps.Serialization]]
uuid = "9e88b42a-f829-5b0c-bbe9-9e923198166b"

[[deps.SnoopPrecompile]]
deps = ["Preferences"]
git-tree-sha1 = "e760a70afdcd461cf01a575947738d359234665c"
uuid = "66db9d55-30c0-4569-8b51-7e840670fc0c"
version = "1.0.3"

[[deps.Sockets]]
uuid = "6462fe0b-24de-5631-8697-dd941f90decc"

[[deps.SortingAlgorithms]]
deps = ["DataStructures"]
git-tree-sha1 = "c60ec5c62180f27efea3ba2908480f8055e17cee"
uuid = "a2af1166-a08f-5f64-846c-94a0d3cef48c"
version = "1.1.1"

[[deps.SparseArrays]]
deps = ["Libdl", "LinearAlgebra", "Random", "Serialization", "SuiteSparse_jll"]
uuid = "2f01184e-e22b-5df5-ae63-d93ebab69eaf"

[[deps.Statistics]]
deps = ["LinearAlgebra", "SparseArrays"]
uuid = "10745b16-79ce-11e8-11f9-7d13ad32a3b2"
version = "1.9.0"

[[deps.StatsAPI]]
deps = ["LinearAlgebra"]
git-tree-sha1 = "45a7769a04a3cf80da1c1c7c60caf932e6f4c9f7"
uuid = "82ae8749-77ed-4fe6-ae5f-f523153014b0"
version = "1.6.0"

[[deps.StatsBase]]
deps = ["DataAPI", "DataStructures", "LinearAlgebra", "LogExpFunctions", "Missings", "Printf", "Random", "SortingAlgorithms", "SparseArrays", "Statistics", "StatsAPI"]
git-tree-sha1 = "75ebe04c5bed70b91614d684259b661c9e6274a4"
uuid = "2913bbd2-ae8a-5f71-8c99-4fb6c76f3a91"
version = "0.34.0"

[[deps.StringManipulation]]
git-tree-sha1 = "46da2434b41f41ac3594ee9816ce5541c6096123"
uuid = "892a3eda-7b42-436c-8928-eab12a02cf0e"
version = "0.3.0"

[[deps.SuiteSparse_jll]]
deps = ["Artifacts", "Libdl", "Pkg", "libblastrampoline_jll"]
uuid = "bea87d4a-7f5b-5778-9afe-8cc45184846c"
version = "5.10.1+6"

[[deps.TOML]]
deps = ["Dates"]
uuid = "fa267f1f-6049-4f14-aa54-33bafae1ed76"
version = "1.0.3"

[[deps.TableTraits]]
deps = ["IteratorInterfaceExtensions"]
git-tree-sha1 = "c06b2f539df1c6efa794486abfb6ed2022561a39"
uuid = "3783bdb8-4a98-5b6b-af9a-565f29a5fe9c"
version = "1.0.1"

[[deps.Tables]]
deps = ["DataAPI", "DataValueInterfaces", "IteratorInterfaceExtensions", "LinearAlgebra", "OrderedCollections", "TableTraits", "Test"]
git-tree-sha1 = "1544b926975372da01227b382066ab70e574a3ec"
uuid = "bd369af6-aec1-5ad0-b16a-f7cc5008161c"
version = "1.10.1"

[[deps.Tar]]
deps = ["ArgTools", "SHA"]
uuid = "a4e569a6-e804-4fa4-b0f3-eef7a1d5b13e"
version = "1.10.0"

[[deps.TensorCore]]
deps = ["LinearAlgebra"]
git-tree-sha1 = "1feb45f88d133a655e001435632f019a9a1bcdb6"
uuid = "62fd8b95-f654-4bbd-a8a5-9c27f68ccd50"
version = "0.1.1"

[[deps.Test]]
deps = ["InteractiveUtils", "Logging", "Random", "Serialization"]
uuid = "8dfed614-e22c-5e08-85e1-65c5234f0b40"

[[deps.TranscodingStreams]]
deps = ["Random", "Test"]
git-tree-sha1 = "9a6ae7ed916312b41236fcef7e0af564ef934769"
uuid = "3bb67fe8-82b1-5028-8e26-92a6c54297fa"
version = "0.9.13"

[[deps.Tricks]]
git-tree-sha1 = "aadb748be58b492045b4f56166b5188aa63ce549"
uuid = "410a4b4d-49e4-4fbc-ab6d-cb71b17b3775"
version = "0.1.7"

[[deps.URIs]]
git-tree-sha1 = "b7a5e99f24892b6824a954199a45e9ffcc1c70f0"
uuid = "5c2747f8-b7ea-4ff2-ba2e-563bfd36b1d4"
version = "1.5.0"

[[deps.UUIDs]]
deps = ["Random", "SHA"]
uuid = "cf7118a7-6976-5b1a-9a39-7adc72f591a4"

[[deps.UnPack]]
git-tree-sha1 = "387c1f73762231e86e0c9c5443ce3b4a0a9a0c2b"
uuid = "3a884ed6-31ef-47d7-9d2a-63182c4928ed"
version = "1.0.2"

[[deps.Unicode]]
uuid = "4ec0a83e-493e-50e2-b9ac-8f72acf5a8f5"

[[deps.WeakRefStrings]]
deps = ["DataAPI", "InlineStrings", "Parsers"]
git-tree-sha1 = "b1be2855ed9ed8eac54e5caff2afcdb442d52c23"
uuid = "ea10d353-3f73-51f8-a26c-33c1cb351aa5"
version = "1.4.2"

[[deps.WorkerUtilities]]
git-tree-sha1 = "cd1659ba0d57b71a464a29e64dbc67cfe83d54e7"
uuid = "76eceee3-57b5-4d4a-8e66-0e911cebbf60"
version = "1.6.1"

[[deps.Zlib_jll]]
deps = ["Libdl"]
uuid = "83775a58-1f1d-513f-b197-d71354ab007a"
version = "1.2.13+0"

[[deps.libblastrampoline_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "8e850b90-86db-534c-a0d3-1478176c7d93"
version = "5.8.0+0"

[[deps.nghttp2_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "8e850ede-7688-5339-a07c-302acd2aaf8d"
version = "1.48.0+0"

[[deps.p7zip_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "3f19e933-33d8-53b3-aaab-bd5110c3b7a0"
version = "17.4.0+0"
"""

# ╔═╡ Cell order:
# ╟─20222023-0236-0003-0000-000000000003
# ╟─20222023-0236-0003-0000-000000000004
# ╟─73318fbe-9f98-4c53-8cf7-a43f4a6b0979
# ╟─f2d282fa-8f08-49b9-9d81-c4cb507ff75a
# ╟─9a192d29-9b7c-40a0-9c70-d392e684ddfc
# ╟─c1e263c9-5b33-41a8-ba01-ee05a4fb6ecc
# ╟─46598cde-557e-4564-958b-9d3c3df029ed
# ╟─20222023-0236-0003-0001-000000000001
# ╟─20222023-0236-0003-0001-000000000002
# ╟─20222023-0236-0003-0001-000000000003
# ╟─810e0feb-4061-4461-8d58-fbe72634f8df
# ╟─20222023-0236-0003-0002-000000000001
# ╟─20222023-0236-0003-0002-000000000002
# ╟─20222023-0236-0003-0002-000000000003
# ╟─22ae6f1e-8a54-4a36-9ac2-bb96b2c92bae
# ╟─20222023-0236-0003-0003-000000000001
# ╟─20222023-0236-0003-0003-000000000002
# ╟─20222023-0236-0003-0003-000000000003
# ╟─bb8cfda6-3efb-4c17-b99b-cc195690518a
# ╟─20222023-0236-0003-0004-000000000001
# ╟─20222023-0236-0003-0004-000000000002
# ╟─20222023-0236-0003-0004-000000000003
# ╟─276db795-6ab4-4501-81c6-88392a9d63c1
# ╟─20222023-0236-0003-0005-000000000000
# ╟─20222023-0236-0003-0005-000000000001
# ╠═a427ead0-0317-4c00-9cf8-fb162cd771c2
# ╠═5a10b2ee-1cc6-4bdd-b793-d7e584b410e5
# ╠═38424a48-bc9e-471d-9773-171fd8effb55
# ╟─20222023-0236-0003-0005-000000000002
# ╟─20222023-0236-0003-0005-000000000003
# ╟─de3e42e5-c0a7-4cda-b57c-71e26acef295
# ╟─20222023-0236-0003-0006-000000000001
# ╟─20222023-0236-0003-0006-000000000002
# ╟─20222023-0236-0003-0006-000000000003
# ╟─92dcdd60-e9a0-42e8-beca-15122a00171b
# ╟─20222023-0236-0003-0007-000000000001
# ╟─20222023-0236-0003-0007-000000000002
# ╟─20222023-0236-0003-0007-000000000003
# ╟─f8a19733-f839-41ab-94bc-b8499dfbb0eb
# ╟─20222023-0236-0003-0008-000000000001
# ╟─20222023-0236-0003-0008-000000000002
# ╟─20222023-0236-0003-0008-000000000003
# ╟─5b356213-6c8d-4d2c-a6fd-08cab027ea76
# ╟─20222023-0236-0003-0009-000000000010
# ╟─20222023-0236-0003-0009-000000000001
# ╟─20222023-0236-0003-0009-000000000002
# ╟─20222023-0236-0003-0009-000000000003
# ╟─5c281d9c-6dc0-40c5-96de-b44362a9a5dd
# ╟─20222023-0236-0003-0010-000000000001
# ╟─20222023-0236-0003-0010-000000000002
# ╟─20222023-0236-0003-0010-000000000003
# ╟─8126a8db-43b0-4510-86b0-d988054cd77a
# ╟─9031631e-3aa7-46de-973d-dbfa668bf18b
# ╟─bece237e-83f1-41b5-a759-1c2934ddc57b
# ╟─20222023-0236-0003-0011-000000000001
# ╟─20222023-0236-0003-0011-000000000002
# ╟─20222023-0236-0003-0011-000000000003
# ╟─563b85f3-c11e-4e9a-a98e-8d6b91be2d2d
# ╟─2d8c34ef-9697-4d36-a66c-83fc800ef447
# ╟─20222023-0236-0003-0012-000000000001
# ╟─20222023-0236-0003-0012-000000000002
# ╟─20222023-0236-0003-0012-000000000003
# ╟─06cd1a6f-a464-4961-8c23-f3c089075fab
# ╟─be4a5d64-8da8-419e-9b5c-4b66aac99cc4
# ╟─20222023-0236-0003-0013-000000000001
# ╟─20222023-0236-0003-0013-000000000002
# ╟─20222023-0236-0003-0013-000000000003
# ╟─e0b75cb6-72fa-4c04-ac91-ae029f45bc74
# ╟─20222023-0236-0003-0014-000000000001
# ╟─20222023-0236-0003-0014-000000000002
# ╟─20222023-0236-0003-0014-000000000003
# ╟─6ee3b122-0946-4a07-ae46-8e8823f9c390
# ╟─b31c69f6-b072-4e95-aada-3d07a0e89481
# ╟─20222023-0236-0003-0015-000000000001
# ╟─20222023-0236-0003-0015-000000000002
# ╟─20222023-0236-0003-0015-000000000003
# ╟─f24078ee-706e-48cf-8a44-4fa19e78b4c4
# ╟─f39350c4-2bf9-4e4a-8b8f-01bb4da07dc7
# ╟─20222023-0236-0003-0016-000000000001
# ╟─20222023-0236-0003-0016-000000000002
# ╟─20222023-0236-0003-0016-000000000003
# ╟─01ba3e57-e781-4daf-a17f-56acf8534000
# ╟─20222023-0236-0003-0017-000000000001
# ╟─20222023-0236-0003-0017-000000000002
# ╟─20222023-0236-0003-0017-000000000003
# ╟─7706ce55-864e-41cb-bd94-707d04565701
# ╟─20222023-0236-0003-0018-000000000001
# ╟─20222023-0236-0003-0018-000000000002
# ╟─20222023-0236-0003-0018-000000000003
# ╟─6661f1d5-b9bc-450e-a628-50b4c9325b86
# ╟─20222023-0236-0003-0019-000000000000
# ╟─20222023-0236-0003-0019-000000000001
# ╠═f87ae88e-587e-4b9a-98b7-b2e4f4d72f90
# ╟─20222023-0236-0003-0019-000000000002
# ╟─20222023-0236-0003-0019-000000000003
# ╟─2dba2b8f-adfa-4900-a9df-222ca680cced
# ╟─20222023-0236-0003-0020-000000000001
# ╟─20222023-0236-0003-0020-000000000002
# ╟─20222023-0236-0003-0020-000000000003
# ╟─bd7c437b-c704-4072-bf25-2cb4b69d6c86
# ╟─20222023-0236-0003-0021-000000000000
# ╟─20222023-0236-0003-0021-000000000001
# ╟─20222023-0236-0003-0021-000000000002
# ╟─20222023-0236-0003-0021-000000000003
# ╟─3ff3352b-8674-4213-929f-1591dc54039d
# ╟─20222023-0236-0003-0022-000000000001
# ╟─20222023-0236-0003-0022-000000000002
# ╟─20222023-0236-0003-0022-000000000003
# ╟─876643b7-e47a-425f-994b-66827243fbfd
# ╟─20222023-0236-0003-0023-000000000001
# ╟─20222023-0236-0003-0023-000000000002
# ╟─20222023-0236-0003-0023-000000000003
# ╟─6b3d603d-9bcb-467a-bbcb-4d499dfcf252
# ╟─20222023-0236-0003-0024-000000000001
# ╟─20222023-0236-0003-0024-000000000002
# ╟─20222023-0236-0003-0024-000000000003
# ╟─b9e82ce1-c5b0-4354-8fdd-791755a0f0fc
# ╟─20222023-0236-0003-0025-000000000001
# ╟─20222023-0236-0003-0025-000000000002
# ╟─20222023-0236-0003-0025-000000000003
# ╟─3eb0d1e6-3e1e-454e-8939-ba79bc3e1a8e
# ╟─20222023-0236-0003-0026-000000000001
# ╟─20222023-0236-0003-0026-000000000002
# ╟─20222023-0236-0003-0026-000000000003
# ╟─6c350a26-356e-46a5-98d9-fa5e212cef37
# ╟─20222023-0236-0003-0027-000000000001
# ╟─20222023-0236-0003-0027-000000000002
# ╟─20222023-0236-0003-0027-000000000003
# ╟─e698d7f3-9048-456a-8968-854c9f93039a
# ╟─20222023-0236-0003-0028-000000000001
# ╟─20222023-0236-0003-0028-000000000002
# ╟─20222023-0236-0003-0028-000000000003
# ╟─c2d1b414-105d-4ece-8a56-c1a77711a5a4
# ╟─20222023-0236-0003-0029-000000000000
# ╟─20222023-0236-0003-0029-000000000010
# ╟─20222023-0236-0003-0029-000000000001
# ╟─20222023-0236-0003-0029-000000000002
# ╟─20222023-0236-0003-0029-000000000003
# ╟─141c66a1-dd4b-4ac8-9401-57a7378f0d25
# ╟─20222023-0236-0003-0030-000000000000
# ╟─20222023-0236-0003-0030-000000000010
# ╟─20222023-0236-0003-0030-000000000001
# ╟─20222023-0236-0003-0030-000000000002
# ╟─20222023-0236-0003-0030-000000000003
# ╟─e514f09f-d5eb-4dcc-bc40-483df518ac4c
# ╟─20222023-0236-0003-0031-000000000001
# ╟─20222023-0236-0003-0031-000000000002
# ╟─20222023-0236-0003-0031-000000000003
# ╟─a6c509c0-0f40-424f-bf04-21d414fb7782
# ╟─20222023-0236-0003-0032-000000000001
# ╟─20222023-0236-0003-0032-000000000002
# ╟─20222023-0236-0003-0032-000000000003
# ╟─d22481a4-9808-4704-bd68-cb77bc5b9d7c
# ╟─20222023-0236-0003-0033-000000000001
# ╟─20222023-0236-0003-0033-000000000002
# ╟─20222023-0236-0003-0033-000000000003
# ╟─1edac556-b332-483b-a1fa-141121ec7126
# ╟─20222023-0236-0003-0034-000000000001
# ╟─20222023-0236-0003-0034-000000000002
# ╟─20222023-0236-0003-0034-000000000003
# ╟─7a823207-4466-422b-8758-8d8ac83543d9
# ╟─20222023-0236-0003-0035-000000000001
# ╟─20222023-0236-0003-0035-000000000002
# ╟─20222023-0236-0003-0035-000000000003
# ╟─0bacb266-e7a9-4f3c-95da-730a43521bf3
# ╟─20222023-0236-0003-0036-000000000001
# ╟─20222023-0236-0003-0036-000000000002
# ╟─20222023-0236-0003-0036-000000000003
# ╟─f841871c-f733-409b-82b3-a0609f14d8e1
# ╟─bb4a77e6-916c-4d8a-b834-6a36fef20e6f
# ╟─20222023-0236-0003-0037-000000000001
# ╟─20222023-0236-0003-0037-000000000002
# ╟─20222023-0236-0003-0037-000000000003
# ╟─15e00bf4-b1a4-41db-a403-fb69b58d12c3
# ╟─20222023-0236-0003-0038-000000000001
# ╟─20222023-0236-0003-0038-000000000002
# ╟─20222023-0236-0003-0038-000000000003
# ╟─76a66aed-8337-4f05-ae43-a36182da4954
# ╟─20222023-0236-0003-0039-000000000001
# ╟─20222023-0236-0003-0039-000000000002
# ╟─20222023-0236-0003-0039-000000000003
# ╟─d7781804-b765-4ee9-b7b4-cd15e7d318d6
# ╟─20222023-0236-0003-0040-000000000001
# ╟─20222023-0236-0003-0040-000000000002
# ╟─20222023-0236-0003-0040-000000000003
# ╟─a868f533-c016-49bc-83bd-3c992bc764c8
# ╟─4d9a23a3-dccd-42e3-af0a-1f1f1f8cc73b
# ╟─9f2fdf90-9194-47ab-b7c1-b00d765920a4
# ╟─51fea41d-0689-4472-80f8-a400f7c999fe
# ╟─852b8a1e-ee2f-4ff0-b6a1-82c85abb4299
# ╟─20222023-0236-0003-0000-000000000000
# ╟─433e93a2-492f-4931-9418-20f1296f3051
# ╟─20222023-0236-0003-0000-000000000002
# ╟─bdf49d4c-985d-457e-b31f-7aab9a17552c
# ╟─20222023-0236-0003-0000-000000000001
# ╟─00000000-0000-0000-0000-000000000001
# ╟─00000000-0000-0000-0000-000000000002
